@@ -175,7 +175,6 @@ require_init_pre_rb (void)
 void
 kz_rb_ext_init (gpointer initial_address)
 {
-    gchar *dirname;
     char *argv[] = {"kazehakase"};
 
     kz_rb_ext_ruby_init();
@@ -193,16 +192,13 @@ kz_rb_ext_init (gpointer initial_address)
         _kz_rb_ext_version = g_strdup(StringValueCStr(version));
     }
 
-    dirname = g_build_filename(KZ_GET_SYSTEM_KZ_DATA_DIR, "ext", "ruby", NULL);
-    rb_ary_unshift(rb_load_path, rb_str_new2(dirname));
-    g_free(dirname);
-
     rb_ary_unshift(rb_load_path, rb_str_new2(KZ_GET_SYSTEM_RUBY_EXT_DIR));
+    rb_ary_unshift(rb_load_path, rb_str_new2(KZ_GET_SYSTEM_RUBY_EXT_DATA_DIR));
 
     Init_kz();
     require_init_pre_rb();
     if (RTEST(rb_const_get(mKz, rb_intern("ENABLE")))) {
-        _kz_rb_app_init(mKz, kz_app);
+        _kz_rb_app_init(mKz, kz_app_get());
         _kz_rb_window_init(mKz);
         _kz_rb_notebook_init(mKz);
         _kz_rb_statusbar_init(mKz);
