@@ -20,6 +20,8 @@
 
 #include "kz-module-impl.h"
 
+#define MOZILLA_CLIENT
+
 #include "kz-embed-prefs.h"
 #include "kz-gecko-single.h"
 
@@ -53,8 +55,8 @@
 #include <nsIDocumentViewer.h>
 #include <nsIWebBrowser.h>
 #include <nsIDOMMouseEvent.h>
-#include <dom/nsIDOMKeyEvent.h>
-#include <dom/nsIDOMNSHTMLElement.h>
+#include <nsIDOMKeyEvent.h>
+#include <nsIDOMNSHTMLElement.h>
 #include <nsIDOMHTMLElement.h>
 #include <nsIDOMHTMLDocument.h>
 #include <nsIDOMHTMLTextAreaElement.h>
@@ -63,13 +65,14 @@
 #include <nsIDOMDocumentFragment.h>
 #include <nsIDOMSerializer.h>
 #include <nsIDOMText.h>
-#include <webbrowserpersist/nsIWebBrowserPersist.h>
+#include <nsIWebBrowserPersist.h>
 #include <nsIWebBrowserFind.h>
 #include <nsIFind.h>
-#include <dom/nsIDOMNSDocument.h>
-#include <dom/nsIDOMNSEvent.h>
+#include <nsIDOMNSDocument.h>
+#include <nsIDOMNSEvent.h>
 #include <nsIDOMNodeList.h>
 #include <nsIDOMWindow.h>
+#include <nsIDOMEventTarget.h>
 #include <nsISelection.h>
 #include <nsIDOMRange.h>
 #include <nsIDOMWindow.h>
@@ -80,7 +83,7 @@
 #include <nsISHistoryInternal.h>
 #include <nsIWebNavigation.h>
 #include <nsCWebBrowserPersist.h>
-#include <widget/nsIBaseWindow.h>
+#include <nsIBaseWindow.h>
 #include <nsIWebPageDescriptor.h>
 #include <nsICommandManager.h>
 #include <nsTime.h>
@@ -93,11 +96,9 @@
 #include <nsMemory.h>
 #include <nsILocalFile.h>
 #include <nsIDOM3Node.h>
-#include <nsBuildID.h>
 #include <nsIPrefService.h>
 #include <nsIFontEnumerator.h>
 #include <nsISimpleEnumerator.h>
-#include <nsIFontList.h>
 #include <nsMemory.h>
 
 #define KZ_GECKO_EMBED_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_GECKO_EMBED, KzGeckoEmbedPrivate))
@@ -1088,9 +1089,7 @@ net_stop_proccess (KzGeckoEmbed *kzembed)
 		NS_UTF16ToCString(value,
 				  NS_CSTRING_ENCODING_UTF8, cValue);
 		nsTime lm (cValue.get(), PR_TRUE);
-		GTime last_modified;
-		LL_DIV(last_modified,
-		       NS_STATIC_CAST(PRTime, lm), PR_USEC_PER_SEC);
+		GTime last_modified = (PRTime)lm / PR_USEC_PER_SEC;
 
 		nsCOMPtr<nsIURI> inURI;
 		nsEmbedCString sURI;
@@ -3208,9 +3207,7 @@ kz_gecko_embed_get_last_modified (KzEmbed *kzembed)
 	NS_UTF16ToCString(value,
 			  NS_CSTRING_ENCODING_UTF8, cValue);
 	nsTime last_modified (cValue.get(), PR_FALSE);
-	LL_DIV (mod_time,
-		NS_STATIC_CAST(PRTime, last_modified), PR_USEC_PER_SEC);
-	return mod_time;
+	return (PRTime)last_modified / PR_USEC_PER_SEC;
 }
 
 
@@ -3518,6 +3515,9 @@ kz_gecko_embed_prefs_get_passwords (KzEmbedPrefs *embed_prefs, GList **passwords
         result = passwordManager->GetEnumerator(getter_AddRefs(passwordEnumerator));
         if (NS_FAILED(result)) return FALSE; 
 
+#ifndef HAVE_NSIPASSWORD_H
+	return FALSE;
+#else
         PRBool enumResult;
         for (passwordEnumerator->HasMoreElements(&enumResult) ;
              enumResult == PR_TRUE ;
@@ -3548,6 +3548,7 @@ kz_gecko_embed_prefs_get_passwords (KzEmbedPrefs *embed_prefs, GList **passwords
 	*passwords = g_list_reverse (*passwords);
 
 	return TRUE;
+#endif
 }
 
 static gboolean
