@@ -30,6 +30,9 @@
 #endif /* HAVE_CONFIG_H */
 
 #include "kazehakase.h"
+
+#define MOZILLA_CLIENT
+
 #include "kz-mozwrapper.h"
 #include <gtkmozembed_internal.h>
 
@@ -42,12 +45,20 @@
 #include <nsIDocShell.h>
 #include <nsIDocShellTreeItem.h>
 #include <nsIDocShellTreeOwner.h>
+#define nsAString_h___
+#include <nsIContent.h>
+#undef nsAString_h___
+#define nsString_h___
+#include <nsIPrintOptions.h>
+#undef nsString_h___
 #include <nsIContentViewer.h>
 #include <nsIDOMHTMLDocument.h>
 #include <nsIDOMHTMLElement.h>
 #include <nsIDOMHTMLImageElement.h>
 #include <nsIDOMNSHTMLElement.h>  
 #include <nsIDOMDocumentRange.h>
+#include <nsIDOMDocumentView.h>
+#include <nsIDOMAbstractView.h>
 #include <nsIDOMNamedNodeMap.h>
 #include <nsIDOMText.h>
 #include <nsIDOMNodeList.h>
@@ -56,6 +67,7 @@
 #define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
 #undef MOZILLA_STRICT_API
+#include <nsIDOMEventTarget.h>
 #include <nsIDOMElement.h>
 #include <nsIDOMDocumentType.h>
 #include <nsIURI.h>
@@ -80,10 +92,22 @@
 #include <nsISupportsPrimitives.h>
 #include <nsIDOM3Document.h>
 #include <nsIDocCharset.h>
+
+#ifdef HAVE_NSIPRESCONTEXT_H
+#  include <nsIPresContext.h>
+#else
+typedef nsString              nsAFlatString;
+typedef nsCString             nsAFlatCString;
+#  define nsString_h___
+#  define nsAString_h___
+#  include <nsPresContext.h>
+#  undef nsAString_h___
+#  undef nsString_h___
+#endif
+
 #include "kz-mozprogresslistener.h"
 #include "kz-mozutils.h"
 #include "utils.h"
-#include "MozillaPrivate.h"
 #include "kz-bookmark.h"
 
 # include <nsISSLStatus.h>
@@ -414,7 +438,7 @@ KzMozWrapper::GetBodyString (nsAString &string)
 	if (!range)
 		return NS_ERROR_FAILURE;
 
-	MozillaPrivate::GetRootRange(domDoc, range);
+	GetRootRange(domDoc, range);
 	range->ToString(string);
 
 	return NS_OK;
@@ -442,7 +466,7 @@ KzMozWrapper::GetStringSelection (nsAString &string, gboolean backward)
 
 	mDOMWindow->GetSelection(getter_AddRefs(selection));
 
-	MozillaPrivate::GetSelectedRange(domDoc, range, selection, backward);
+	GetSelectedRange(domDoc, range, selection, backward);
 
 	range->ToString(string);
 
@@ -535,15 +559,19 @@ KzMozWrapper::GetWebNavigation (nsIWebNavigation **aWebNavigation)
 	rv = GetFocusedDOMWindow (getter_AddRefs(DOMWindow));
 	if (NS_FAILED(rv) || !DOMWindow) return NS_ERROR_FAILURE;
 
-	nsCOMPtr<nsIScriptGlobalObject> scriptGlobal = do_QueryInterface(DOMWindow);
-	if (!scriptGlobal) return NS_ERROR_FAILURE;
+	nsCOMPtr<nsIDOMDocument> domDocument;
+	rv = DOMWindow->GetDocument(getter_AddRefs(domDocument));
+	if (NS_FAILED(rv) || !domDocument) return NS_ERROR_FAILURE;
 
-	nsIDocShell *docshell = scriptGlobal->GetDocShell();
-	if (!docshell)
-		return NS_ERROR_FAILURE;
-	
-	nsCOMPtr<nsIWebNavigation> wn = do_QueryInterface (docshell, &rv);
-	if (!wn || !NS_SUCCEEDED (rv)) return NS_ERROR_FAILURE;
+	nsCOMPtr<nsIDOMDocumentView> docView(do_QueryInterface(domDocument));
+	if (!docView) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIDOMAbstractView> abstractView;
+	rv = docView->GetDefaultView(getter_AddRefs(abstractView));
+	if (NS_FAILED(rv) || !abstractView) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIWebNavigation> wn = do_QueryInterface(abstractView, &rv);
+	if (NS_FAILED(rv) || !wn) return NS_ERROR_FAILURE;
 
 	NS_IF_ADDREF(*aWebNavigation = wn);
 	return NS_OK;
@@ -1372,7 +1400,9 @@ KzMozWrapper::Print (void)
 	if (NS_FAILED(rv) || !print) return NS_ERROR_FAILURE;
 
 	print->GetGlobalPrintSettings(getter_AddRefs(options));
+#if HAVE_NSIPRINTSETTINGS_SETPAPERSIZE
 	options->SetPaperSize(nsIPrintSettings::kPaperSizeNativeData);
+#endif
 	options->SetPrintSilent(PR_FALSE);
 	
 //	KzMozProgressListener *aProgress = new KzMozProgressListener();
@@ -1393,7 +1423,9 @@ KzMozWrapper::PrintPreview (void)
 	if (NS_FAILED(rv) || !print) return NS_ERROR_FAILURE;
 
 	print->GetGlobalPrintSettings(getter_AddRefs(options));
+#if HAVE_NSIPRINTSETTINGS_SETPAPERSIZE
 	options->SetPaperSize(nsIPrintSettings::kPaperSizeNativeData);
+#endif
 	rv = print->PrintPreview(options, mDOMWindow, nsnull);
 
 	return rv;
@@ -1403,7 +1435,46 @@ KzMozWrapper::PrintPreview (void)
 nsresult
 KzMozWrapper::GetPrinterList (GList **list)
 {
-	*list = MozillaPrivate::GetPrinterList();
+	GList *printers = NULL;
+	nsresult rv = NS_OK;
+
+#ifndef HAVE_NSIPRINTOPTIONS_AVAILABLEPRINTERS
+	*list = NULL;
+#else
+	nsCOMPtr<nsIPrintSettingsService> pss =
+		do_GetService("@mozilla.org/gfx/printsettings-service;1", &rv);
+	NS_ENSURE_SUCCESS(rv, nsnull);
+
+	nsCOMPtr<nsIPrintOptions> po = do_QueryInterface(pss, &rv);
+	NS_ENSURE_SUCCESS(rv, nsnull);
+
+	nsCOMPtr<nsISimpleEnumerator> avPrinters;
+	rv = po->AvailablePrinters(getter_AddRefs(avPrinters));
+	NS_ENSURE_SUCCESS(rv, nsnull);
+
+	PRBool more = PR_FALSE;
+
+	for (avPrinters->HasMoreElements(&more);
+	     more == PR_TRUE;
+	     avPrinters->HasMoreElements(&more))
+	{
+		nsCOMPtr<nsISupports> i;
+		rv = avPrinters->GetNext(getter_AddRefs(i));
+		NS_ENSURE_SUCCESS(rv, nsnull);
+
+		nsCOMPtr<nsISupportsString> printer = do_QueryInterface(i, &rv);
+		NS_ENSURE_SUCCESS(rv, nsnull);
+
+		nsAutoString data;
+		rv = printer->GetData(data);
+		NS_ENSURE_SUCCESS(rv, nsnull);
+
+		printers = g_list_prepend (printers, g_strdup (NS_ConvertUCS2toUTF8 (data).get()));
+	}
+
+	*list = g_list_reverse (printers);
+#endif
+
 	return NS_OK;
 }
 
@@ -1459,7 +1530,7 @@ KzMozWrapper::SetZoom (float aZoom, PRBool reflow)
 nsresult
 KzMozWrapper::SetZoomOnDocshell (float aZoom, nsIDocShell *DocShell)
 {
-	gboolean ret = MozillaPrivate::SetZoomOnDocShell(aZoom, DocShell);
+	gboolean ret = SetZoomOnDocShell(aZoom, DocShell);
 
 	if (!ret) return NS_ERROR_FAILURE;
 
@@ -2029,10 +2100,133 @@ KzMozWrapper::CreateThumbnail (const gchar *uri,
 	nsCOMPtr<nsIDOMWindow> domWindow;
 	GetDOMWindow(getter_AddRefs(domWindow));
 
-	if (!MozillaPrivate::CreateThumbnail(domWindow, uri,
-					     last_modified, size))
+// 	if (!MozillaPrivate::CreateThumbnail(domWindow, uri,
+// 					     last_modified, size))
 		return NS_ERROR_FAILURE;
 
 	return NS_OK;
 }
 #endif
+
+gboolean
+KzMozWrapper::GetRootRange (nsIDOMDocument *domDoc, nsIDOMRange *range)
+{
+	nsCOMPtr<nsIContent> rootContent;
+	nsCOMPtr<nsIDOMHTMLDocument> htmlDoc = do_QueryInterface(domDoc);
+	if (htmlDoc)
+	{
+		nsCOMPtr<nsIDOMHTMLElement> bodyElement;
+		htmlDoc->GetBody(getter_AddRefs(bodyElement));
+		rootContent = do_QueryInterface(bodyElement);
+	}
+
+        // to avoid segfault with DetailedPreference, 
+        // return if rootContent is NULL.
+	if (!rootContent)
+		return FALSE;
+
+	nsCOMPtr<nsIDOMNode> rootNode(do_QueryInterface(rootContent));
+
+	PRUint32 childcount;
+	childcount = rootContent->GetChildCount();
+	
+	range->SetStart(rootNode,0);
+	range->SetEnd(rootNode,childcount);
+
+	return TRUE;
+}
+
+gboolean
+KzMozWrapper::GetSelectedRange (nsIDOMDocument *domDoc,
+				nsIDOMRange *range,
+				nsISelection *selection,
+				gboolean backward)
+{
+	nsCOMPtr<nsIContent> rootContent;
+	nsCOMPtr<nsIDOMHTMLDocument> htmlDoc = do_QueryInterface(domDoc);
+	if (htmlDoc)
+	{
+		nsCOMPtr<nsIDOMHTMLElement> bodyElement;
+		htmlDoc->GetBody(getter_AddRefs(bodyElement));
+		rootContent = do_QueryInterface(bodyElement);
+	}
+
+        // to avoid segfault with DetailedPreference, 
+        // return if rootContent is NULL.
+	if (!rootContent)
+		return FALSE;
+
+	// Get root content node
+	nsCOMPtr<nsIDOMNode> rootNode(do_QueryInterface(rootContent));
+
+	PRUint32 childcount;
+	childcount = rootContent->GetChildCount();
+	
+	if (backward)
+	{
+		if (selection)
+		{
+			nsCOMPtr<nsIDOMNode> endNode;
+			PRInt32 endOffset;
+			selection->CollapseToStart();
+			selection->GetAnchorNode(getter_AddRefs(endNode));
+			selection->GetAnchorOffset(&endOffset);
+	
+			range->SetEnd(endNode, endOffset);
+		}
+		else
+		{
+			range->SetEnd(rootNode, childcount);
+		}
+		range->SetStart(rootNode, 0);
+	}
+	else
+	{
+		if (selection)
+		{
+			nsCOMPtr<nsIDOMNode> endNode;
+			PRInt32 endOffset;
+			selection->GetAnchorNode(getter_AddRefs(endNode));
+			selection->GetAnchorOffset(&endOffset);
+	
+			range->SetStart(endNode, endOffset + 1);
+		}
+		else
+		{
+			range->SetStart(rootNode, 0);
+		}
+		range->SetEnd(rootNode, childcount);
+	}
+
+	return TRUE;
+}
+
+gboolean
+KzMozWrapper::SetZoomOnDocShell (float aZoom, nsIDocShell *DocShell)
+{
+#ifdef HAVE_NSIPRESCONTEXT_H
+	nsCOMPtr<nsIPresContext> PresContext;
+#else
+	nsCOMPtr<nsPresContext> PresContext;
+#endif
+	nsresult rv = DocShell->GetPresContext (getter_AddRefs(PresContext));
+	if (NS_FAILED(rv) || !PresContext) return FALSE;
+
+	nsIDeviceContext *DeviceContext(nsnull);
+	DeviceContext = PresContext->DeviceContext();
+	if (!DeviceContext) return FALSE;
+
+	nsCOMPtr<nsIContentViewer> ContentViewer;
+	
+	rv = DocShell->GetContentViewer(getter_AddRefs(ContentViewer));
+	if (NS_FAILED(rv) || !ContentViewer) return FALSE;
+
+	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(ContentViewer);
+	if (!mdv) return FALSE;
+
+	rv = mdv->SetTextZoom (aZoom);
+
+	if NS_FAILED(rv) return FALSE;
+	
+	return TRUE;
+}
