@@ -27,6 +27,7 @@
 #include "kazehakase.h"
 #include "kz-icons.h"
 #include "kz-navi.h"
+#include "kz-statusbar.h"
 
 #define KZ_ACTIONS_DYNAMIC_COPY_IN_USER_FORMAT_KEY "KzActionsDynamic::CopyInUserFormat"
 #define KZ_ACTIONS_DYNAMIC_SMART_LIST_KEY "KzActionsDynamic::SmartList"
@@ -54,6 +55,7 @@ cb_copy_in_user_format_menuitem_activate (GtkWidget *menuitem, KzTabLabel *kztab
 	gchar *text;
 	gchar *str;
 	gchar *compress_str;
+	gchar *statusbar_message;
 	gint i;
 	gint counts = 0;
 
@@ -161,10 +163,14 @@ cb_copy_in_user_format_menuitem_activate (GtkWidget *menuitem, KzTabLabel *kztab
 	compress_str = g_strcompress(str);
 
 	gtkutil_copy_text(compress_str);
+	
+	statusbar_message = g_strconcat("Copy to clipboard ", compress_str, NULL);
+	kz_statusbar_set_copied_text(KZ_STATUSBAR(kztab->kz->statusbar), statusbar_message);
 
 	if(str) g_free(str);
 	if(compress_str) g_free(compress_str);
 	if(text) g_free(text);
+	if(statusbar_message) g_free(statusbar_message);
 }
 
 void
