@@ -742,7 +742,7 @@ kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 
 		if (tablist_submenu)
 		{
-			gtk_menu_item_remove_submenu(GTK_MENU_ITEM(tablist_menu));
+			gtk_menu_item_set_submenu(GTK_MENU_ITEM(tablist_menu), NULL);
 		}
         	/* append tablist menuitem */
 		tablist_submenu = gtk_menu_new();
