@@ -23,7 +23,6 @@
 
 #include <glib/gi18n.h>
 #include "kazehakase.h"
-#include "gobject-utils.h"
 #include "kz-favicon.h"
 #include "kz-icons.h"
 
@@ -33,33 +32,23 @@ enum {
 };
 
 
-static void kz_navigation_action_class_init       (KzNavigationActionClass *class);
-static void kz_navigation_action_init             (KzNavigationAction      *action);
-static void kz_navigation_action_dispose          (GObject *obj);
-static void kz_navigation_action_set_property     (GObject           *object,
-						   guint              prop_id,
-						   const GValue      *value,
-						   GParamSpec        *pspec);
-static void kz_navigation_action_get_property     (GObject           *object,
-						   guint              prop_id,
-						   GValue            *value,
-						   GParamSpec        *pspec);
-static void kz_navigation_action_connect_proxy    (GtkAction         *action,
-						   GtkWidget         *proxy);
-static void kz_navigation_action_activate         (GtkAction         *action);
-#if 0
-static void kz_navigation_action_disconnect_proxy (GtkAction         *action,
-						   GtkWidget         *proxy);
-#endif
-static void cb_menu_activated                     (GtkMenuToolButton *b,
-						   KzNavigationAction *action);
-static GtkActionClass *parent_class = NULL;
+static void dispose          (GObject *obj);
+static void set_property     (GObject           *object,
+                              guint              prop_id,
+                              const GValue      *value,
+                              GParamSpec        *pspec);
+static void get_property     (GObject           *object,
+                              guint              prop_id,
+                              GValue            *value,
+                              GParamSpec        *pspec);
+static void connect_proxy    (GtkAction         *action,
+                              GtkWidget         *proxy);
+static void activate         (GtkAction         *action);
 
+static void cb_menu_activated   (GtkMenuToolButton *b,
+                                 KzNavigationAction *action);
 
-KZ_OBJECT_GET_TYPE(kz_navigation_action, "KzNavigationAction", KzNavigationAction,
-		   kz_navigation_action_class_init, kz_navigation_action_init,
-		   GTK_TYPE_ACTION)
-
+G_DEFINE_TYPE(KzNavigationAction, kz_navigation_action, GTK_TYPE_ACTION)
 
 static void
 kz_navigation_action_class_init (KzNavigationActionClass *klass)
@@ -67,17 +56,16 @@ kz_navigation_action_class_init (KzNavigationActionClass *klass)
 	GObjectClass *object_class;
 	GtkActionClass *action_class;
 
-	parent_class = g_type_class_peek_parent(klass);
 	object_class = G_OBJECT_CLASS(klass);
 	action_class = GTK_ACTION_CLASS(klass);
 
-	object_class->set_property     = kz_navigation_action_set_property;
-	object_class->get_property     = kz_navigation_action_get_property;
-	object_class->dispose          = kz_navigation_action_dispose;
+	object_class->set_property     = set_property;
+	object_class->get_property     = get_property;
+	object_class->dispose          = dispose;
 
 	action_class->toolbar_item_type = GTK_TYPE_MENU_TOOL_BUTTON;
-	action_class->connect_proxy     = kz_navigation_action_connect_proxy;
-	action_class->activate          = kz_navigation_action_activate;
+	action_class->connect_proxy     = connect_proxy;
+	action_class->activate          = activate;
 
 	g_object_class_install_property
 		(object_class,
@@ -99,7 +87,7 @@ kz_navigation_action_init (KzNavigationAction *action)
 
 
 static void
-kz_navigation_action_dispose (GObject *obj)
+dispose (GObject *obj)
 {
 	KzNavigationAction *action = KZ_NAVIGATION_ACTION(obj);
 
@@ -107,16 +95,16 @@ kz_navigation_action_dispose (GObject *obj)
 		g_object_unref(action->kz);
 	action->kz = NULL;
 
-	if (G_OBJECT_CLASS(parent_class)->dispose)
-		G_OBJECT_CLASS(parent_class)->dispose(obj);
+	if (G_OBJECT_CLASS(kz_navigation_action_parent_class)->dispose)
+		G_OBJECT_CLASS(kz_navigation_action_parent_class)->dispose(obj);
 }
 
 
 static void
-kz_navigation_action_set_property (GObject         *object,
-				   guint            prop_id,
-				   const GValue    *value,
-				   GParamSpec      *pspec)
+set_property (GObject         *object,
+              guint            prop_id,
+              const GValue    *value,
+              GParamSpec      *pspec)
 {
 	KzNavigationAction *action = KZ_NAVIGATION_ACTION(object);
   
@@ -133,10 +121,10 @@ kz_navigation_action_set_property (GObject         *object,
 
 
 static void
-kz_navigation_action_get_property (GObject         *object,
-				   guint            prop_id,
-				   GValue          *value,
-				   GParamSpec      *pspec)
+get_property (GObject         *object,
+              guint            prop_id,
+              GValue          *value,
+              GParamSpec      *pspec)
 {
 	KzNavigationAction *action = KZ_NAVIGATION_ACTION(object);
 
@@ -152,7 +140,7 @@ kz_navigation_action_get_property (GObject         *object,
 }
 
 static void
-kz_navigation_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
+connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
 	GtkWidget *menu;
 
@@ -169,20 +157,12 @@ kz_navigation_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 		}
 	}
 
-	(* GTK_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
+	(* GTK_ACTION_CLASS (kz_navigation_action_parent_class)->connect_proxy) (action, proxy);
 }
 
 
-#if 0
 static void
-kz_navigation_action_disconnect_proxy (GtkAction *action, GtkWidget *proxy)
-{
-	GTK_ACTION_CLASS (parent_class)->disconnect_proxy (action, proxy);
-}
-#endif
-
-static void
-kz_navigation_action_activate (GtkAction *action)
+activate (GtkAction *action)
 {
 	GtkWidget *widget;
 
@@ -222,7 +202,7 @@ cb_menu_activated (GtkMenuToolButton *b, KzNavigationAction *action)
 	int i, pos, count;
 	GtkWidget *menu;
 	KzEmbed *kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(action->kz));
-	KzFavicon *kzfav = action->kz->kzfav;
+	KzFavicon *kzfav = KZ_GET_FAVICON;
 
 	menu = gtk_menu_tool_button_get_menu(b);
 	if (menu)
