@@ -109,10 +109,10 @@ kz_bookmark_filter_out (KzBookmark *bookmark)
 
 		regex = g_regex_new(exp, 0, 0, NULL);
 
-		match = g_regex_match(regex, str, 0);
+		match = g_regex_match(regex, str, 0, NULL);
 
 		g_free(exp);
-		g_regex_free(regex);
+		g_regex_unref(regex);
 
 		if (match)
 			return TRUE;
