@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-item.c 3268 2007-10-04 21:54:50Z ikezoe $
+ *  $Id: kz-bookmark-item.c 3321 2007-12-15 10:56:19Z kous $
  */
 
 #include "kz-bookmark-item.h"
@@ -34,6 +34,7 @@
 #include "kz-bookmark-editor.h"
 #include "kz-bookmark-utils.h"
 #include "kz-icons.h"
+#include "kz-notebook.h"
 #include "kz-actions.h"
 #include "gtk-utils.h"
 
@@ -44,6 +45,7 @@ enum {
 };
 
 enum {
+	TARGET_GTK_NOTEBOOK_TAB,
 	TARGET_KAZEHAKASE_BOOKMARKS,
 	TARGET_NETSCAPE_URL,
 	TARGET_TEXT_URI_LIST
@@ -55,6 +57,7 @@ static const GtkTargetEntry dnd_types[] = {
 
 static const GtkTargetEntry url_drag_types [] = 
 {
+	{"GTK_NOTEBOOK_TAB", GTK_TARGET_SAME_APP, TARGET_GTK_NOTEBOOK_TAB},
 	{"_KAZEHAKASE_BOOKMARKS", 0, TARGET_KAZEHAKASE_BOOKMARKS},
         { "_NETSCAPE_URL",        0, TARGET_NETSCAPE_URL},
 	{ "text/uri-list",        0, TARGET_TEXT_URI_LIST}
@@ -665,6 +668,19 @@ cb_drag_data_received (GtkWidget        *widget,
 	item = KZ_BOOKMARK_ITEM(widget);
 	switch (info)
 	{
+	 case TARGET_GTK_NOTEBOOK_TAB:
+	 {
+	 	KzEmbed *kzembed;
+		const gchar *uri, *title;
+		src_widget = gtk_drag_get_source_widget(context);
+		if (!KZ_IS_NOTEBOOK(src_widget))
+			break;
+		kzembed = KZ_EMBED(kz_notebook_get_dragged_page(KZ_NOTEBOOK(src_widget)));
+		uri   = kz_embed_get_location(kzembed);
+		title = kz_embed_get_title(kzembed);
+		bookmark = KZ_BOOKMARK(kz_bookmark_new_with_attrs(title, uri, NULL));
+	 	break;
+	 }
 	 case TARGET_KAZEHAKASE_BOOKMARKS:
 		src_widget = gtk_drag_get_source_widget(context);
 		
