@@ -18,13 +18,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-proxy-folder.c,v 1.6 2005/02/13 13:20:34 ikezoe Exp $
+ *  $Id: kz-proxy-folder.c 2785 2007-01-06 00:28:47Z ikezoe $
  */
 
 #include "kz-proxy-folder.h"
 
 #include <glib/gi18n.h>
-#include "gobject-utils.h"
 
 typedef struct _KzProxyFolderPriv KzProxyFolderPriv;
 struct _KzProxyFolderPriv
@@ -39,21 +38,19 @@ enum {
 	PROP_KZ_BOOKMARK
 };
 
-static void     kz_proxy_folder_class_init   (KzProxyFolderClass *klass);
-static void     kz_proxy_folder_init         (KzProxyFolder      *proxy_folder);
-static GObject *kz_proxy_folder_constructor  (GType type,
-					      guint n_props,
-					      GObjectConstructParam *props);
-static void     kz_proxy_folder_dispose      (GObject            *object);
+static GObject *constructor  (GType type,
+                              guint n_props,
+                              GObjectConstructParam *props);
+static void     dispose      (GObject            *object);
 
-static void     kz_proxy_folder_set_property (GObject            *object,
-					      guint               prop_id,
-					      const GValue       *value,
-					      GParamSpec         *pspec);
-static void     kz_proxy_folder_get_property (GObject            *object,
-					      guint               prop_id,
-					      GValue             *value,
-					      GParamSpec         *pspec);
+static void     set_property (GObject            *object,
+			      guint               prop_id,
+			      const GValue       *value,
+			      GParamSpec         *pspec);
+static void     get_property (GObject            *object,
+                              guint               prop_id,
+                              GValue             *value,
+                              GParamSpec         *pspec);
 
 static void     cb_folder_insert_child	     (KzBookmark    *folder,
 					      KzBookmark    *child,
@@ -63,26 +60,19 @@ static void     cb_folder_remove_child       (KzBookmark    *folder,
 					      KzBookmark    *child,
 					      KzProxyFolder *proxy);
 
-static KzBookmarkClass *parent_class = NULL;
-
-
-KZ_OBJECT_GET_TYPE(kz_proxy_folder, "KzProxyFolder", KzProxyFolder,
-		   kz_proxy_folder_class_init, kz_proxy_folder_init,
-		   KZ_TYPE_BOOKMARK)
-
+G_DEFINE_TYPE(KzProxyFolder, kz_proxy_folder, KZ_TYPE_BOOKMARK)
 
 static void
 kz_proxy_folder_class_init (KzProxyFolderClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->constructor  = kz_proxy_folder_constructor;
-	object_class->dispose      = kz_proxy_folder_dispose;
-	object_class->set_property = kz_proxy_folder_set_property;
-	object_class->get_property = kz_proxy_folder_get_property;
+	object_class->constructor  = constructor;
+	object_class->dispose      = dispose;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 	g_object_class_install_property
 		(object_class,
 		 PROP_KZ_BOOKMARK,
@@ -109,7 +99,7 @@ static KzBookmark *
 create_current_page_bookmark (KzBookmark *tab)
 {
 	KzBookmark *cur_page;
-	gint cur_pos;
+	guint cur_pos;
 	GList *pages;
 	KzBookmark *new;
 
@@ -119,10 +109,9 @@ create_current_page_bookmark (KzBookmark *tab)
 	cur_page = KZ_BOOKMARK(g_list_nth_data(pages, cur_pos));
 	g_list_free(pages);
 
-	new = kz_bookmark_new_with_attrs(kz_bookmark_get_title(cur_page),
-					 kz_bookmark_get_link(cur_page),
+	new = kz_bookmark_new_with_attrs(cur_page ? kz_bookmark_get_title(cur_page) : "",
+					 cur_page ? kz_bookmark_get_link(cur_page) : "",
 					 NULL);
-
 	return new;
 }
 
@@ -148,12 +137,12 @@ create_proxy_folder (KzProxyFolder *proxy, KzBookmark *tabs)
 
 
 static GObject*
-kz_proxy_folder_constructor (GType type,
-			     guint n_props,
-			     GObjectConstructParam *props)
+constructor (GType type,
+             guint n_props,
+             GObjectConstructParam *props)
 {
 	GObject *object;
-	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
+	GObjectClass *klass = G_OBJECT_CLASS(kz_proxy_folder_parent_class);
 	KzProxyFolder *proxy;
 	KzProxyFolderPriv *priv;
 
@@ -163,18 +152,18 @@ kz_proxy_folder_constructor (GType type,
 
 	/* set signals */
 	g_signal_connect(priv->bookmark, "insert-child",
-			       G_CALLBACK(cb_folder_insert_child),
-			       proxy);
+			 G_CALLBACK(cb_folder_insert_child),
+			 proxy);
 	g_signal_connect(priv->bookmark, "remove-child",
-			       G_CALLBACK(cb_folder_remove_child),
-			       proxy);
+			 G_CALLBACK(cb_folder_remove_child),
+			 proxy);
 
 	return object;
 }
 
 
 static void
-kz_proxy_folder_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzProxyFolder *proxy = KZ_PROXY_FOLDER(object);
 	KzProxyFolderPriv *priv = KZ_PROXY_FOLDER_GET_PRIVATE(object);
@@ -193,16 +182,16 @@ kz_proxy_folder_dispose (GObject *object)
 	}
 	priv->bookmark = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_proxy_folder_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_proxy_folder_parent_class)->dispose(object);
 }
 
 
 static void
-kz_proxy_folder_set_property (GObject *object,
-			      guint prop_id,
-			      const GValue *value,
-			      GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzProxyFolderPriv *priv = KZ_PROXY_FOLDER_GET_PRIVATE(object);
   
@@ -219,10 +208,10 @@ kz_proxy_folder_set_property (GObject *object,
 
 
 static void 
-kz_proxy_folder_get_property (GObject *object,
-			      guint prop_id,
-			      GValue *value,
-			      GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzProxyFolderPriv *priv = KZ_PROXY_FOLDER_GET_PRIVATE(object);
 
@@ -260,6 +249,7 @@ cb_folder_insert_child (KzBookmark *folder,
 {
 	KzBookmark *new;
 	KzProxyFolderPriv *priv = KZ_PROXY_FOLDER_GET_PRIVATE(proxy);
+
 	new = create_current_page_bookmark(child);
 
 	if (sibling)
