@@ -19,6 +19,8 @@
  */
 
 #include "kz-about-dialog.h"
+#include "kz-embed.h"
+#include "kz-module.h"
 
 #include <glib/gi18n.h>
 
@@ -31,7 +33,7 @@ N_("Takuro Ashie <ashie@homa.ne.jp>\n"
 #endif
 
 static const gchar *copyright = 
-N_("Copyright (C) 2002-2006 Kazehakase Project");
+N_("Copyright (C) 2002-2007 Kazehakase Project");
 
 static	GtkWidget *bg_pixmap   = NULL;
 static	GtkWidget *logo_pixmap = NULL;
@@ -42,12 +44,37 @@ static  int bg_height;
 static  int logo_width;
 static  int logo_height;
 
+static gchar *
+backend_names(void)
+{
+	GString *names;
+	GList *node, *backends;
+
+	names = g_string_new("");
+	backends = kz_embed_engine_names();
+	for (node = backends; node; node = g_list_next(node))
+	{
+		gchar *name = node->data;
+
+		if (names->len == 0)
+			g_string_append(names, name);
+		else if (g_list_next(node))
+			g_string_append_printf(names, ", %s", name);
+		else
+			g_string_append_printf(names, "and %s", name);
+		g_free(name);
+	}
+	g_list_free(backends);
+
+	return g_string_free(names, names->len == 0);
+}
+
 static gboolean
 cb_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer data)
 {
 	PangoLayout *copyright_layout, *info_layout;
 	PangoRectangle link, logical;
-	gchar *version, *powered_by, *info;
+	gchar *version, *backends, *info;
 
 	/* Draw background image */
 	gdk_draw_pixbuf(widget->window,
@@ -69,8 +96,19 @@ cb_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer data)
 			0, 0);
 	/* Draw version and backends under the logo */
 	version = g_strdup_printf (_("Version %s"), VERSION);
-	powered_by = g_strdup_printf (_("Powered by %s"), KZ_BACKENDS);
-	info = g_strdup_printf ("%s\n%s", version, powered_by);
+	backends = backend_names();
+	if (backends)
+	{
+		gchar *powered_by;
+		powered_by = g_strdup_printf(_("Powered by %s"), backends);
+		info = g_strdup_printf("%s\n%s", version, powered_by);
+		g_free(backends);
+		g_free(powered_by);
+	}
+	else
+	{
+		info = g_strdup(version);
+	}
 	info_layout = gtk_widget_create_pango_layout (widget, info);
 	pango_layout_set_alignment(info_layout, PANGO_ALIGN_RIGHT);
 	pango_layout_get_pixel_extents(info_layout, &link, &logical);
@@ -79,12 +117,11 @@ cb_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer data)
 			bg_width - logical.width, logo_height,
 			info_layout);
 	g_free (version);
-	g_free (powered_by);
 	g_free (info);
 	g_object_unref(info_layout);
 
 	/* Draw copyright at bottom right */
-	copyright_layout = gtk_widget_create_pango_layout (widget, 
+	copyright_layout = gtk_widget_create_pango_layout (widget,
 							   _(copyright));
 	pango_layout_set_alignment(copyright_layout, PANGO_ALIGN_RIGHT);
 	pango_layout_set_width(copyright_layout, -1);
@@ -100,7 +137,7 @@ cb_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer data)
 
 
 void
-kz_about_dialog_new (KzWindow *kz)
+kz_about_dialog_new (GtkWindow *parent_window)
 {
 	GtkWidget *about_dialog;
 	GtkWidget *calendar;
@@ -115,12 +152,12 @@ kz_about_dialog_new (KzWindow *kz)
 	gchar     *logo_name;
 
 	about_dialog = gtk_dialog_new_with_buttons(_("About Kazehakase"),
-						   GTK_WINDOW(kz),
+						   parent_window,
 						   GTK_DIALOG_DESTROY_WITH_PARENT,
 						   GTK_STOCK_OK,
 						   GTK_RESPONSE_NONE,
 						   NULL);
-						   
+
 	gtk_window_set_type_hint (GTK_WINDOW (about_dialog),
 				  GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_window_set_wmclass (GTK_WINDOW (about_dialog),
@@ -128,14 +165,16 @@ kz_about_dialog_new (KzWindow *kz)
 	gtk_window_set_position (GTK_WINDOW (about_dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_resizable (GTK_WINDOW (about_dialog), FALSE);
 
-	pixmap_name = g_strconcat(KZ_DATADIR, "/icons/kz-logo-bg.png", NULL);
+	pixmap_name = g_build_filename(KZ_GET_SYSTEM_ICONS_DIR,
+				       "kz-logo-bg.png", NULL);
 	bg_pixmap = gtk_image_new_from_file(pixmap_name);
 	image = gtk_image_get_pixbuf(GTK_IMAGE(bg_pixmap));
 	bg_width  = gdk_pixbuf_get_width(image);
 	bg_height = gdk_pixbuf_get_height(image);
 	g_free(pixmap_name);
 
-	logo_name = g_strconcat(KZ_DATADIR, "/icons/kz-logo.png", NULL);
+	logo_name = g_build_filename(KZ_GET_SYSTEM_ICONS_DIR,
+				     "kz-logo.png", NULL);
 	logo_pixmap = gtk_image_new_from_file(logo_name);
 	logo = gtk_image_get_pixbuf(GTK_IMAGE(logo_pixmap));
 	logo_width  = gdk_pixbuf_get_width(logo);
