@@ -53,9 +53,17 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 #include "kz-tab-label.h"
 #include "kz-window.h"
 #include "kz-history-utils.h"
+#include "kz-marshalers.h"
 #include "glib-utils.h"
 #include "utils.h"
 
+#include "egg-pixbuf-thumbnail-type-builtins.h"
+
+enum {
+	THUMBNAIL_CREATED_SIGNAL,
+	LAST_SIGNAL
+};
+
 enum {
 	PROP_0,
 	PROP_ARGC,
@@ -91,12 +99,21 @@ struct _KzAppPrivate
 	gchar		*form_data_dir;
 	gchar		*clips_dir;
 	gchar		*thumbnails_dir;
+
 	gchar		*system_data_dir;
 	gchar		*system_kz_data_dir;
-	gchar		*system_ruby_ext_dir;
+	gchar		*system_lib_dir;
 	gchar		*system_config_dir;
+
 	gchar		*system_icons_dir;
 	gchar		*system_pixmaps_dir;
+
+	gchar		*system_embed_module_dir;
+	gchar		*system_search_module_dir;
+
+	gchar		*system_ext_dir;
+	gchar		*system_ruby_ext_dir;
+	gchar		*system_ruby_ext_data_dir;
 };
 
 #define KZ_APP_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_APP, KzAppPrivate))
@@ -120,10 +137,18 @@ static void     cb_destroy_window (GtkObject *object, gpointer data);
 static void     connect_sm   (KzApp *app);
 #endif /* HAVE_LIBSM */
 
-static KzApp    *the_kzapp = NULL;
+static KzApp    *the_kz_app = NULL;
+
+KzApp *
+kz_app_get (void)
+{
+	return the_kz_app;
+}
 
 G_DEFINE_TYPE(KzApp, kz_app, G_TYPE_OBJECT)
 
+static gint kz_app_signals[LAST_SIGNAL] = {0};
+
 static void
 kz_app_class_init (KzAppClass *klass)
 {
@@ -136,7 +161,19 @@ kz_app_class_init (KzAppClass *klass)
 	object_class->dispose	   = dispose;
 	object_class->set_property = set_property;
 	object_class->get_property = get_property;
-	
+
+	klass->thumbnail_created = NULL;
+
+	kz_app_signals[THUMBNAIL_CREATED_SIGNAL]
+		= g_signal_new("thumbnail-created",
+			       G_TYPE_FROM_CLASS (klass),
+			       G_SIGNAL_RUN_FIRST,
+			       G_STRUCT_OFFSET (KzAppClass, thumbnail_created),
+			       NULL, NULL,
+			       _kz_marshal_VOID__STRING_ENUM,
+			       G_TYPE_NONE, 2,
+			       G_TYPE_STRING, EGG_TYPE_PIXBUF_THUMB_SIZE);
+
 	g_object_class_install_property(
 		object_class,
 		PROP_ARGC,
@@ -164,7 +201,7 @@ constructor (GType                  type,
 {
 	GObject *object;
 
-	if (!the_kzapp) 
+	if (!the_kz_app) 
 	{
 		GObjectClass *klass = G_OBJECT_CLASS(kz_app_parent_class);
 		object = klass->constructor(type, n_props, props);
@@ -174,11 +211,11 @@ constructor (GType                  type,
 		connect_sm(KZ_APP(object));
 #endif /* HAVE_LIBSM */
 
-		the_kzapp = KZ_APP(object);
+		the_kz_app = KZ_APP(object);
 	}
 	else
 	{
-		object = g_object_ref(G_OBJECT(the_kzapp));
+		object = g_object_ref(G_OBJECT(the_kz_app));
 	}
 	return object;
 }
@@ -275,15 +312,30 @@ kz_app_init_path (KzApp *app)
 						 "share", NULL);
 	priv->system_kz_data_dir = g_build_filename(priv->system_data_dir,
 						    PACKAGE, NULL);
-	priv->system_ruby_ext_dir = g_build_filename(priv->system_kz_data_dir,
-						     "ext", "ruby", NULL);
+	priv->system_lib_dir = g_build_filename(kz_win32_base_path(),
+						"lib", PACKAGE, NULL);
 	priv->system_config_dir = g_build_filename(kz_win32_base_path(),
 						   "etc", PACKAGE, NULL);
+
+	priv->system_embed_module_dir = g_build_filename(priv->system_lib_dir,
+							 "embed", NULL);
+	priv->system_search_module_dir = g_build_filename(priv->system_lib_dir,
+							  "search", NULL);
+
+	priv->system_ext_dir = g_strdup(priv->system_lib_dir);
+	priv->system_ruby_ext_dir = g_build_filename(priv->system_ext_dir,
+						     "ruby", NULL);
 #else
 	priv->system_data_dir = g_strdup(DATADIR);
 	priv->system_kz_data_dir = g_strdup(KZ_DATADIR);
-	priv->system_ruby_ext_dir = g_strdup(KZ_RUBY_EXTDIR);
 	priv->system_config_dir = g_strdup(KZ_SYSCONFDIR);
+	priv->system_lib_dir = g_strdup(KZ_LIBDIR);
+
+	priv->system_embed_module_dir = g_strdup(KZ_EMBED_MODULEDIR);
+	priv->system_search_module_dir = g_strdup(KZ_SEARCH_MODULEDIR);
+
+	priv->system_ext_dir = g_strdup(KZ_EXTDIR);
+	priv->system_ruby_ext_dir = g_strdup(KZ_RUBY_EXTDIR);
 #endif
 
 	priv->system_icons_dir = g_build_filename(priv->system_kz_data_dir,
@@ -291,6 +343,9 @@ kz_app_init_path (KzApp *app)
 	priv->system_pixmaps_dir = g_build_filename(priv->system_data_dir,
 						    "pixmaps", NULL);
 
+	priv->system_ruby_ext_data_dir =
+		g_build_filename(priv->system_kz_data_dir, "ext", "ruby", NULL);
+
 	ensure_directories(app);
 }
 
@@ -308,13 +363,22 @@ kz_app_dispose_path (GObject *app)
 	g_free(priv->form_data_dir);
 	g_free(priv->clips_dir);
 	g_free(priv->thumbnails_dir);
+
 	g_free(priv->system_data_dir);
 	g_free(priv->system_kz_data_dir);
-	g_free(priv->system_ruby_ext_dir);
+	g_free(priv->system_lib_dir);
 	g_free(priv->system_config_dir);
+
 	g_free(priv->system_icons_dir);
 	g_free(priv->system_pixmaps_dir);
 
+	g_free(priv->system_embed_module_dir);
+	g_free(priv->system_search_module_dir);
+
+	g_free(priv->system_ext_dir);
+	g_free(priv->system_ruby_ext_dir);
+	g_free(priv->system_ruby_ext_data_dir);
+
 	priv->user_dir = NULL;
 	priv->history_dir = NULL;
 	priv->history_time_stamp = NULL;
@@ -324,12 +388,21 @@ kz_app_dispose_path (GObject *app)
 	priv->form_data_dir = NULL;
 	priv->clips_dir = NULL;
 	priv->thumbnails_dir = NULL;
+
 	priv->system_data_dir = NULL;
 	priv->system_kz_data_dir = NULL;
-	priv->system_ruby_ext_dir = NULL;
+	priv->system_lib_dir = NULL;
 	priv->system_config_dir = NULL;
+
 	priv->system_icons_dir = NULL;
 	priv->system_pixmaps_dir = NULL;
+
+	priv->system_embed_module_dir = NULL;
+	priv->system_search_module_dir = NULL;
+
+	priv->system_ext_dir = NULL;
+	priv->system_ruby_ext_dir = NULL;
+	priv->system_ruby_ext_data_dir = NULL;
 }
 
 #define DEFINE_PATH_GETTER(name)			\
@@ -350,13 +423,22 @@ DEFINE_PATH_GETTER(smartbookmark_history_dir)
 DEFINE_PATH_GETTER(form_data_dir)
 DEFINE_PATH_GETTER(clips_dir)
 DEFINE_PATH_GETTER(thumbnails_dir)
+
 DEFINE_PATH_GETTER(system_data_dir)
 DEFINE_PATH_GETTER(system_kz_data_dir)
-DEFINE_PATH_GETTER(system_ruby_ext_dir)
+DEFINE_PATH_GETTER(system_lib_dir)
 DEFINE_PATH_GETTER(system_config_dir)
+
 DEFINE_PATH_GETTER(system_icons_dir)
 DEFINE_PATH_GETTER(system_pixmaps_dir)
 
+DEFINE_PATH_GETTER(system_embed_module_dir)
+DEFINE_PATH_GETTER(system_search_module_dir)
+
+DEFINE_PATH_GETTER(system_ext_dir)
+DEFINE_PATH_GETTER(system_ruby_ext_dir)
+DEFINE_PATH_GETTER(system_ruby_ext_data_dir)
+
 
 static void
 kz_app_init (KzApp *app)
@@ -496,8 +578,6 @@ dispose (GObject *object)
 	g_free(accel_prefs_file);
 
 	kz_root_bookmark_save_all(priv->bookmarks);
-	/* freeze session for storing last saving session */
-	kz_session_freeze(KZ_SESSION(priv->bookmarks->current_session));
 	g_object_unref(G_OBJECT(priv->bookmarks));
 
 	kz_profile_close(priv->profile);
@@ -627,10 +707,14 @@ kz_app_restore_session (KzApp *app)
 	priv = KZ_APP_GET_PRIVATE(app);
 
 	/* close all tabs before loading session file */
-	kz_session_freeze(KZ_SESSION(priv->bookmarks->current_session));
+	kz_app_freeze_session(app);
 	for (node = priv->window_list; node; node = g_list_next(node))
-		kz_window_close_all_tab(KZ_WINDOW(node->data));
-	kz_session_thaw(KZ_SESSION(priv->bookmarks->current_session));
+	{
+		KzWindow *kz = KZ_WINDOW(node->data);
+		kz_bookmark_remove(priv->bookmarks->current_session,
+				   kz->tabs);
+		kz_window_close_all_tab(kz);
+	}
 
 	session = priv->bookmarks->current_session;
 	location = kz_bookmark_file_get_location(KZ_BOOKMARK_FILE(session));
@@ -667,6 +751,7 @@ kz_app_restore_session (KzApp *app)
 		KzWindow *window = KZ_WINDOW(window_node->data);
 		gtk_widget_destroy(GTK_WIDGET(window));
 	}
+	kz_app_thaw_session(app);
 
 	/* if there is no window, create a window */
 	if (!priv->window_list)
@@ -683,6 +768,12 @@ kz_app_create_new_window (KzApp *app, const gchar *uri)
 
 	window = kz_window_new(uri);
 
+	if (!kz_session_is_frozen(KZ_SESSION(priv->bookmarks->current_session)))
+	{
+		kz_bookmark_append(priv->bookmarks->current_session,
+				   KZ_WINDOW(window)->tabs);
+	}
+
 	g_signal_connect(window, "destroy",
 			 G_CALLBACK(cb_destroy_window), app);
 	priv->window_list = g_list_append(priv->window_list, window);
@@ -831,10 +922,34 @@ kz_app_get_window_from_tab (KzApp *app, GtkWidget *tab_widget)
 	return NULL;
 }
 
+void
+kz_app_freeze_session (KzApp *app)
+{
+	KzAppPrivate *priv;
+
+	g_return_if_fail (KZ_IS_APP(app));
+
+	priv = KZ_APP_GET_PRIVATE(app);
+	kz_session_freeze(KZ_SESSION(priv->bookmarks->current_session));
+}
+
+void
+kz_app_thaw_session (KzApp *app)
+{
+	KzAppPrivate *priv;
+
+	g_return_if_fail (KZ_IS_APP(app));
+
+	priv = KZ_APP_GET_PRIVATE(app);
+	kz_session_thaw(KZ_SESSION(priv->bookmarks->current_session));
+}
+
 static void
 cb_destroy_window (GtkObject *object, gpointer data)
 {
-	KzAppPrivate *priv = KZ_APP_GET_PRIVATE(data);
+	KzApp *app = KZ_APP(data);
+	KzAppPrivate *priv = KZ_APP_GET_PRIVATE(app);
+	KzWindow *kz = KZ_WINDOW (object);
 
 	g_signal_handlers_disconnect_by_func(object,
 					     G_CALLBACK(cb_destroy_window), data);
@@ -845,9 +960,18 @@ cb_destroy_window (GtkObject *object, gpointer data)
 		static gboolean main_quited = FALSE;
 		if (!main_quited)
 		{
+			/* If the window is the last window, keep its tabs for saving the
+			 * session. */
+			kz_app_freeze_session(app);
 			gtk_main_quit();
 			main_quited = TRUE;
 		}
+	} 
+	else
+	{
+		if (kz->tabs)
+			kz_bookmark_remove(priv->bookmarks->current_session,
+					   kz->tabs);
 	}
 }
 
@@ -859,6 +983,38 @@ kz_app_get_migemo (KzApp *app)
 }
 #endif
 
+gboolean
+kz_app_create_thumbnail (KzApp *app,
+			 GdkPixbuf *pixbuf,
+			 const gchar *uri,
+			 time_t mtime,
+			 EggPixbufThumbSize size)
+{
+	GError *error = NULL;
+
+	if (!uri)
+		return FALSE;
+
+	if (uri[0] == '\0')
+		return FALSE;
+
+	if (!egg_pixbuf_add_thumbnail_data(pixbuf, uri, mtime, size))
+		return FALSE;
+
+	if (!egg_pixbuf_save_thumbnail(pixbuf, &error, NULL))
+	{
+		g_warning("create_thumbnail: %s", error->message);
+		g_error_free(error);
+		return FALSE;
+	}
+
+	g_signal_emit(app, kz_app_signals[THUMBNAIL_CREATED_SIGNAL], 0,
+		      uri, size);
+
+	return TRUE;
+}
+
+
 #ifdef HAVE_LIBSM
 
 /* these codes are taken from libgnomeui.*/
