@@ -21,7 +21,6 @@
 #include <stdio.h>
 #include <glib/gi18n.h>
 
-#include "gobject-utils.h"
 #include "kz-downloader.h"
 
 enum {
@@ -38,20 +37,18 @@ enum {
 	PROP_FILENAME
 };
 
-static void     kz_downloader_class_init   (KzDownloaderClass *klass);
-static void     kz_downloader_init         (KzDownloader *downloader);
-static void     kz_downloader_dispose      (GObject *object);
-static GObject *kz_downloader_constructor  (GType type,
-					    guint n_props,
-					    GObjectConstructParam *props);
-static void     kz_downloader_set_property (GObject *object,
-	            			    guint prop_id,
-	            			    const GValue *value,
-	            			    GParamSpec *pspec);
-static void     kz_downloader_get_property (GObject *object,
-					    guint prop_id,
-					    GValue *value,
-					    GParamSpec *pspec);
+static void     dispose      (GObject *object);
+static GObject *constructor  (GType type,
+                              guint n_props,
+                              GObjectConstructParam *props);
+static void     set_property (GObject *object,
+                              guint prop_id,
+                              const GValue *value,
+                              GParamSpec *pspec);
+static void     get_property (GObject *object,
+                              guint prop_id,
+                              GValue *value,
+                              GParamSpec *pspec);
 
 static void kz_downloader_connect_signals    (KzDownloader *downloader);
 static void kz_downloader_disconnect_signals (KzDownloader *downloader);
@@ -67,25 +64,21 @@ static void cb_io_in                       (KzIO *io,
 					    const gchar *buf,
 					    KzDownloader *downloader);
 
-static GObjectClass *parent_class = NULL;
 static gint kz_downloader_signals[LAST_SIGNAL] = {0};
 
-KZ_OBJECT_GET_TYPE(kz_downloader, "KzDownloader", KzDownloader,
-		   kz_downloader_class_init, kz_downloader_init,
-		   G_TYPE_OBJECT)
+G_DEFINE_TYPE(KzDownloader, kz_downloader, G_TYPE_OBJECT)
 
 static void
 kz_downloader_class_init (KzDownloaderClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->constructor  = kz_downloader_constructor;
-	object_class->dispose      = kz_downloader_dispose;
-	object_class->set_property = kz_downloader_set_property;
-	object_class->get_property = kz_downloader_get_property;
+	object_class->constructor  = constructor;
+	object_class->dispose      = dispose;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 
 	klass->start     = NULL;
 	klass->completed = NULL;
@@ -104,7 +97,7 @@ kz_downloader_class_init (KzDownloaderClass *klass)
 			 _("The URI of Target"),
 			 NULL,
 			 G_PARAM_READWRITE |
-			 G_PARAM_CONSTRUCT_ONLY));
+			 G_PARAM_CONSTRUCT));
 	g_object_class_install_property(
 		object_class,
 		 PROP_FILENAME,
@@ -149,7 +142,6 @@ kz_downloader_class_init (KzDownloaderClass *klass)
 				G_TYPE_NONE, 0);
 }
 
-
 static void
 kz_downloader_init (KzDownloader *downloader)
 {
@@ -160,14 +152,14 @@ kz_downloader_init (KzDownloader *downloader)
 
 
 static GObject*
-kz_downloader_constructor (GType                  type,
-			   guint                  n_props,
-			   GObjectConstructParam *props)
+constructor (GType                  type,
+             guint                  n_props,
+             GObjectConstructParam *props)
 {
 	KzDownloader *dl;
 	KzIO *io;
 	GObject *object;
-	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
+	GObjectClass *klass = G_OBJECT_CLASS(kz_downloader_parent_class);
 
 	object = klass->constructor(type, n_props, props);
 
@@ -184,7 +176,7 @@ kz_downloader_constructor (GType                  type,
 }
 
 static void
-kz_downloader_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzDownloader *downloader;
 
@@ -199,16 +191,16 @@ kz_downloader_dispose (GObject *object)
 	downloader->uri      = NULL;
 	downloader->filename = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_downloader_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_downloader_parent_class)->dispose(object);
 }
 
 
 static void
-kz_downloader_set_property (GObject *object,
-			    guint prop_id,
-			    const GValue *value,
-			    GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzDownloader *downloader = KZ_DOWNLOADER(object);
 
@@ -230,10 +222,10 @@ kz_downloader_set_property (GObject *object,
 
 
 static void
-kz_downloader_get_property (GObject *object,
-			    guint prop_id,
-			    GValue *value,
-			    GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzDownloader *downloader = KZ_DOWNLOADER(object);
 
