@@ -23,6 +23,7 @@
 #include "kazehakase.h"
 #include "kz-embed-event.h"
 #include "kz-navi.h"
+#include "egg-pixbuf-thumbnail.h"
 
 #ifndef __KZ_EMBED_H__
 #define __KZ_EMBED_H__
@@ -196,7 +197,8 @@ struct _KzEmbedIFace {
 	void		(*print)		(KzEmbed       *kzembed);
 	void		(*print_preview)	(KzEmbed       *kzembed);
 	GList	       *(*get_printer_list)	(KzEmbed       *kzembed);
-	void		(*create_thumbnail)	(KzEmbed       *kzembed);
+	void		(*create_thumbnail)	(KzEmbed       *kzembed,
+						 EggPixbufThumbSize size);
 
 
 	gboolean	(*save_with_content)	(KzEmbed       *kzembed,
@@ -300,6 +302,7 @@ void            kz_embed_load			(const gchar   *base_dir);
 void            kz_embed_unload			(void);
 void            kz_embed_exit			(void);
 GList	       *kz_embed_engine_names		(void);
+GList	       *kz_embed_engine_ids		(void);
 
 GtkWidget      *kz_embed_new			(const gchar   *name);
 void		kz_embed_load_url		(KzEmbed       *kzembed,
@@ -418,7 +421,8 @@ void		kz_embed_get_encoding		(KzEmbed       *kzembed,
 void		kz_embed_print			(KzEmbed       *kzembed);
 void		kz_embed_print_preview		(KzEmbed       *kzembed);
 GList	       *kz_embed_get_printer_list	(KzEmbed       *kzembed);
-void		kz_embed_create_thumbnail	(KzEmbed       *kzembed);
+void		kz_embed_create_thumbnail	(KzEmbed       *kzembed,
+						 EggPixbufThumbSize size);
 
 
 gboolean	kz_embed_save_with_content	(KzEmbed       *kzembed,
