@@ -34,7 +34,6 @@
 #include "kz-downloader.h"
 #include "kz-profile.h"
 #include "kz-thumbnail.h"
-#include "gobject-utils.h"
 #include "glib-utils.h"
 #include "utils.h"
 #include "eggmd5.h"
@@ -66,9 +65,7 @@ struct _KzPopupPreviewPriv
 #define DEFAULT_POPUP_RESPONSE_DELAY 100
 #define DEFAULT_POPUP_CLOSE_DELAY 100
 
-static void       kz_popup_preview_class_init             (KzPopupPreviewClass *klass);
-static void       kz_popup_preview_init                   (KzPopupPreview *popup);
-static void       kz_popup_preview_dispose                (GObject *object);
+static void       dispose                (GObject *object);
 
 static gboolean   cb_enter_notify_event                   (GtkWidget *widget,
 							   GdkEventCrossing *event,
@@ -107,22 +104,18 @@ static GdkPixbuf* gdk_pixbuf_scale_keeping_aspect_ratio   (const GdkPixbuf *src,
 							   int              max_height,
 							   GdkInterpType    interp_type);
 
-static GObjectClass *parent_class = NULL;
 static KzPopupPreview      *kz_popup_preview_single = NULL;
 
-KZ_OBJECT_GET_TYPE(kz_popup_preview, "KzPopupPreview", KzPopupPreview,
-		   kz_popup_preview_class_init, kz_popup_preview_init,
-		   G_TYPE_OBJECT)
+G_DEFINE_TYPE(KzPopupPreview, kz_popup_preview, G_TYPE_OBJECT)
 
 static void
 kz_popup_preview_class_init (KzPopupPreviewClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose = kz_popup_preview_dispose;
+	object_class->dispose = dispose;
 
 	g_type_class_add_private (klass, sizeof(KzPopupPreviewPriv));
 }
@@ -153,7 +146,7 @@ kz_popup_preview_init (KzPopupPreview *popup)
 }
 
 static void
-kz_popup_preview_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzPopupPreview *popup = KZ_POPUP_PREVIEW (object);
 	KzPopupPreviewPriv *priv = KZ_POPUP_PREVIEW_GET_PRIVATE (popup);
@@ -182,8 +175,8 @@ kz_popup_preview_dispose (GObject *object)
 		priv->popup_window = NULL;
 	}
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_popup_preview_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_popup_preview_parent_class)->dispose(object);
 }
 
 KzPopupPreview *
@@ -502,9 +495,7 @@ kz_popup_preview_get_image (KzPopupPreview *popup, const gchar *uri)
 
 	tmp_name = egg_str_get_md5_str(uri);
 	image_name = g_strconcat(tmp_name, ".png", NULL);
-	popup_file_name = g_build_filename(g_get_home_dir(),
-					   "."PACKAGE,
-					   "popup",
+	popup_file_name = g_build_filename(KZ_GET_POPUP_DIR,
 					   image_name,
 					   NULL);
 	g_free(tmp_name);
