@@ -41,6 +41,7 @@
 #include "prefs_ui/prefs_external_program.h"
 #include "prefs_ui/prefs_history.h"
 #include "prefs_ui/prefs_bookmark.h"
+#include "prefs_ui/prefs_browser.h"
 
 
 enum {
@@ -124,6 +125,7 @@ kz_prefs_win_class_init (KzPrefsWinClass *klass)
 	widget_class->delete_event = delete_event;
 	
 	ADD_PAGE_ENTRY(prefs_general_get_entry);
+	ADD_PAGE_ENTRY(prefs_browser_get_entry);
 	ADD_PAGE_ENTRY(prefs_lang_get_entry);
 	ADD_PAGE_ENTRY(prefs_font_get_entry);
 	ADD_PAGE_ENTRY(prefs_tab_get_entry);
@@ -132,11 +134,11 @@ kz_prefs_win_class_init (KzPrefsWinClass *klass)
 	ADD_PAGE_ENTRY(prefs_key_accel_get_entry);
 	ADD_PAGE_ENTRY(prefs_gesture_get_entry);
 	ADD_PAGE_ENTRY(prefs_proxy_get_entry);
-	ADD_PAGE_ENTRY(prefs_privacy_get_entry); 
+	ADD_PAGE_ENTRY(prefs_privacy_get_entry);
 	/* ADD_PAGE_ENTRY(prefs_ui_editor_get_entry); */
 	ADD_PAGE_ENTRY(prefs_external_program_get_entry);
 	ADD_PAGE_ENTRY(prefs_history_get_entry);
-	
+
 	g_type_class_add_private (object_class, sizeof(KzPrefsWinPrivate));
 }
 
