@@ -22,6 +22,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include "gtk-utils.h"
 #include "kazehakase.h"
@@ -32,6 +33,8 @@
 #include "kz-bookmark-file.h"
 #include "kz-notebook.h"
 
+#include "utils.h"
+
 enum {
 	PROP_0,
 	PROP_KZ_WINDOW,
@@ -75,22 +78,10 @@ static void     get_property (GObject      *object,
 static void     realize        (GtkWidget        *widget);
 static gboolean button_press   (GtkWidget        *widget,
                                 GdkEventButton   *event);
-static gboolean motion_notify  (GtkWidget        *widget,
-                                GdkEventMotion   *event);
 static gboolean button_release (GtkWidget        *widget,
                                 GdkEventButton   *event);
 static gboolean scroll_event   (GtkWidget        *widget,
                                 GdkEventScroll   *event);
-static gboolean drag_motion    (GtkWidget        *widget,
-                                GdkDragContext   *drag_context,
-		   		gint              x,
-                                gint              y,
-		   		guint             time);
-static void     drag_data_get  (GtkWidget        *widget,
-                                GdkDragContext   *context,
-                                GtkSelectionData *seldata,
-                                guint             info,
-                                guint             time);
 static void     drag_data_received (GtkWidget        *widget,
                                     GdkDragContext   *drag_context,
                                     gint              x, 
@@ -100,8 +91,6 @@ static void     drag_data_received (GtkWidget        *widget,
                                     guint             time);
 
 static void     kz_tab_label_sync_to_profile    (KzTabLabel *kztab);
-static void     kz_tab_label_move_page          (KzTabLabel *kztab,
-						 KzTabLabel *dest_kztab);
 
 static void	kz_tab_label_set_visited        (KzTabLabel *kztab);
 
@@ -116,6 +105,7 @@ static void     cb_profile_changed              (KzProfile *profile,
 
 /* callbacks for embed */
 static void cb_title_changed (KzEmbed *embed, KzTabLabel *kztab);
+static void cb_location_changed (KzEmbed *embed, KzTabLabel *kztab);
 static void cb_net_start     (KzEmbed *embed, KzTabLabel *kztab);
 static void cb_net_stop      (KzEmbed *embed, KzTabLabel *kztab);
 static void cb_progress      (KzEmbed *embed, KzTabLabel *kztab);
@@ -124,7 +114,6 @@ static void cb_destroy       (GtkObject *object,  KzTabLabel *kztab);
 static void make_progress_circle (GtkWidget *widget);
 
 enum {
-	TARGET_KAZEHAKASE_TAB,
 	TARGET_NETSCAPE_URL,
 	TARGET_TEXT_URI_LIST,
 	TARGET_TEXT_PLAIN,
@@ -133,11 +122,10 @@ enum {
 
 static GtkTargetEntry url_drag_types [] = 
 {
-        { "_KAZEHAKASE_TAB", 0, TARGET_KAZEHAKASE_TAB},
-        { "_NETSCAPE_URL",   0, TARGET_NETSCAPE_URL},
-	{ "text/uri-list",   0, TARGET_TEXT_URI_LIST},
-	{ "text/plain",      0, TARGET_TEXT_PLAIN},
-	{ "STRING",          0, TARGET_STRING}
+        { "_NETSCAPE_URL", 0, TARGET_NETSCAPE_URL},
+	{ "text/uri-list", 0, TARGET_TEXT_URI_LIST},
+	{ "text/plain",    0, TARGET_TEXT_PLAIN},
+	{ "STRING",        0, TARGET_STRING}
 };
 static guint n_url_drag_types = G_N_ELEMENTS (url_drag_types);
 
@@ -165,9 +153,7 @@ kz_tab_label_class_init (KzTabLabelClass *klass)
 	widget_class->button_press_event   = button_press;
 	widget_class->button_release_event = button_release;
 	widget_class->scroll_event         = scroll_event;
-	widget_class->motion_notify_event  = motion_notify;
-	widget_class->drag_motion          = drag_motion;
-	widget_class->drag_data_get        = drag_data_get;
+
 	widget_class->drag_data_received   = drag_data_received;
 
 	g_object_class_install_property
@@ -211,7 +197,6 @@ kz_tab_label_init (KzTabLabel *kztab)
 	kztab->close_button = gtk_button_new();
 	kztab->lock_button  = gtk_image_new_from_stock(KZ_STOCK_ANCHOR,
 						       GTK_ICON_SIZE_MENU);
-	kztab->tooltips     = gtk_tooltips_new();
 
 	priv->width             = 80;
 	priv->start_x           = 0;
@@ -265,7 +250,7 @@ kz_tab_label_init (KzTabLabel *kztab)
 	style->xthickness = style->ythickness = 0;
 	gtk_widget_modify_style (kztab->close_button, style);
 	gtk_widget_modify_style (kztab->lock_button, style);
-	gtk_rc_style_unref (style),
+	g_object_unref (style),
 
 	gtk_box_pack_start(GTK_BOX(hbox), kztab->favicon,
 			   FALSE, FALSE, 0);
@@ -282,17 +267,8 @@ kz_tab_label_init (KzTabLabel *kztab)
 
 	gtk_widget_show (kztab->close_button);
 
-	gtk_drag_source_set(GTK_WIDGET(kztab),
-			    GDK_BUTTON1_MASK |
-			    GDK_BUTTON2_MASK |
-			    GDK_BUTTON3_MASK,
-			    url_drag_types, n_url_drag_types,
-			    GDK_ACTION_ASK  | GDK_ACTION_COPY
-			    | GDK_ACTION_MOVE | GDK_ACTION_LINK);
 	gtk_drag_dest_set(GTK_WIDGET(kztab), 
-			  GTK_DEST_DEFAULT_HIGHLIGHT |
-			  GTK_DEST_DEFAULT_MOTION | 
-			  GTK_DEST_DEFAULT_DROP,
+			  GTK_DEST_DEFAULT_ALL,
                           url_drag_types,n_url_drag_types,
 			  GDK_ACTION_MOVE);
 
@@ -320,6 +296,8 @@ constructor (GType                  type,
 	/* set signals */
 	g_signal_connect(kztab->kzembed, "kz-title",
 			 G_CALLBACK(cb_title_changed), kztab);
+	g_signal_connect(kztab->kzembed, "kz-location",
+			 G_CALLBACK(cb_location_changed), kztab);
 	g_signal_connect(kztab->kzembed, "kz-net-start",
 			 G_CALLBACK(cb_net_start), kztab);
 	g_signal_connect(kztab->kzembed, "kz-net-stop",
@@ -359,6 +337,8 @@ dispose (GObject *object)
 						     cb_net_stop, kztab);
 		g_signal_handlers_disconnect_by_func(kztab->kzembed,
 						     cb_title_changed, kztab);
+		g_signal_handlers_disconnect_by_func(kztab->kzembed,
+						     cb_location_changed, kztab);
 		g_signal_handlers_disconnect_by_func(kztab->kzembed,
 						     cb_progress, kztab);
 		g_signal_handlers_disconnect_by_func(kztab->kzembed,
@@ -378,6 +358,7 @@ dispose (GObject *object)
 
 	if (kztab->history)
 	{
+		kz_bookmark_set_javascript(kztab->history, priv->javascript);
 		kz_bookmark_remove(kztab->kz->tabs, kztab->history);
 		kz_window_append_closed_tab(kztab->kz, kztab->history);
 		g_object_unref(kztab->history);
@@ -390,12 +371,6 @@ dispose (GObject *object)
 		kztab->kz = NULL;
 	}
 
-	if (kztab->tooltips)
-	{
-		g_object_ref_sink(GTK_OBJECT(kztab->tooltips));
-		kztab->tooltips = NULL;
-	}
-	
 	if (kztab->favicon_pixbuf)
 	{
 		g_object_unref(kztab->favicon_pixbuf);
@@ -494,12 +469,50 @@ kz_tab_label_set_text(KzTabLabel *kztab, const gchar *text)
 				 escaped);
 
 	gtk_label_set_markup(GTK_LABEL(kztab->label), markup);
-	gtk_tooltips_set_tip(kztab->tooltips, GTK_WIDGET(kztab->eventbox),
-			     text, NULL);
+	gtk_widget_set_tooltip_text(GTK_WIDGET(kztab->eventbox), text);
 	g_free(markup);
 	g_free(escaped);
 }
 
+static gboolean
+idle_create_thumbnail (gpointer data)
+{
+	KzTabLabel *kztab;
+	KzEmbed *embed;
+	EggPixbufThumbSize size = EGG_PIXBUF_THUMB_LARGE;
+	gboolean create_thumbnail = FALSE;
+	const gchar *uri;
+	guint last_modified;
+
+	kztab = data;
+	g_return_val_if_fail(KZ_IS_TAB_LABEL(kztab), FALSE);
+
+	KZ_CONF_GET("Global", "create_thumbnail", create_thumbnail, BOOL);
+	if (!create_thumbnail)
+		return FALSE;
+
+	embed = kztab->kzembed;
+	uri = kz_embed_get_location(embed);
+	if (!uri)
+		return FALSE;
+
+	if (uri[0] == '\0')
+		return FALSE;
+
+	last_modified = kz_embed_get_last_modified(embed);
+	if (last_modified > 0)
+	{
+		GTime thumbnail_last_modified;
+
+		thumbnail_last_modified = thumbnail_get_last_modified(uri, size);
+		if ((unsigned int)thumbnail_last_modified >= last_modified)
+			return FALSE;
+	}
+
+	kz_embed_create_thumbnail(embed, size);
+	return FALSE;
+}
+
 void
 kz_tab_label_set_state (KzTabLabel *kztab,
 			KzTabLabelState state)
@@ -510,6 +523,10 @@ kz_tab_label_set_state (KzTabLabel *kztab,
 
 	if (!GTK_WIDGET_REALIZED(kztab)) return;
 
+	if (kztab->state != KZ_TAB_LABEL_STATE_NORMAL &&
+	    state == KZ_TAB_LABEL_STATE_NORMAL)
+		g_idle_add(idle_create_thumbnail, kztab);
+
 	kztab->state = state;
 	if (state == KZ_TAB_LABEL_STATE_NORMAL)
 	{
@@ -624,23 +641,6 @@ button_press (GtkWidget *widget, GdkEventButton *event)
 	return FALSE;
 }
 
-static gboolean
-motion_notify (GtkWidget *widget, GdkEventMotion *event)
-{
-	KzTabLabel *kztab = KZ_TAB_LABEL(widget);
-	KzTabLabelPrivate *priv = KZ_TAB_LABEL_GET_PRIVATE (kztab);
-
-	if (abs(event->x - priv->start_x) > 2 ||
-	    abs(event->y - priv->start_y) > 2)
-	{
-		priv->moved = TRUE;
-	}
-
-	if (GTK_WIDGET_CLASS(kz_tab_label_parent_class)->motion_notify_event)
-		return GTK_WIDGET_CLASS(kz_tab_label_parent_class)->motion_notify_event(widget, event);
-	return FALSE;
-}
-
 static gboolean
 button_release (GtkWidget *widget, GdkEventButton *event)
 {
@@ -687,107 +687,6 @@ scroll_event (GtkWidget *widget, GdkEventScroll *event)
 }
 
 
-static gboolean
-drag_motion (GtkWidget *widget,
-             GdkDragContext *drag_context,
-             gint x, gint y,
-             guint time)
-{
-	KzTabLabel *kztab;
-	KzEmbed *current_kzembed;
-	gint page_num;
-
-	kztab = KZ_TAB_LABEL(widget);
-
-	g_return_val_if_fail (KZ_IS_EMBED(kztab->kzembed), FALSE);
-
-	current_kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kztab->kz));
-
-	if (KZ_EMBED(kztab->kzembed) == current_kzembed)
-		return FALSE;
-
-	page_num = kz_notebook_page_num(KZ_NOTEBOOK(kztab->kz->notebook),
-					GTK_WIDGET(kztab->kzembed));
-	kz_notebook_set_current_page(KZ_NOTEBOOK(kztab->kz->notebook), page_num);
-
-	return FALSE;
-}
-
-static void
-drag_data_get (GtkWidget        *widget,
-               GdkDragContext   *context,
-               GtkSelectionData *data,
-               guint             info,
-               guint             time)
-{
-	KzTabLabel *kztab;
-	const gchar *uri, *title;
-
-	kztab = KZ_TAB_LABEL(widget);
-
-	g_return_if_fail (KZ_IS_EMBED(kztab->kzembed));
-
-	uri   = kz_embed_get_location(kztab->kzembed);
-	title = kz_embed_get_title(kztab->kzembed);
-
-	if (!uri || !*uri) return;
-
-	switch (info)
-	{
-	case TARGET_KAZEHAKASE_TAB:
-		gtk_selection_data_set(data, data->target,
-				       8, (const guchar*)"dummy", strlen("dummy"));
-		break;
-	case TARGET_NETSCAPE_URL:
-	{
-		gchar *str;
-		if (title && *title)
-		{
-			gchar *title_locale;
-			gsize bytes_read, bytes_written;
-			GError *error = NULL;
-
-			title_locale = g_locale_from_utf8(title, -1,
-							  &bytes_read,
-							  &bytes_written,
-							  &error);
-			if (error)
-			{
-				g_warning("kz_tab_label_drag_data_get(): %s",
-					 error->message);
-				g_error_free(error);
-			}
-			if (title_locale && *title_locale)
-			{
-				str = g_strconcat(uri, "\n", title_locale,
-						  NULL);
-				g_free(title_locale);
-			}
-			else
-			{
-				str = g_strdup (uri);
-			}
-		}
-		else
-		{
-			str = g_strdup (uri);
-		}
-		gtk_selection_data_set(data, data->target,
-				       8, (const guchar*)str, strlen(str));
-		g_free(str);
-		break;
-	}
-	case TARGET_TEXT_URI_LIST:
-	case TARGET_TEXT_PLAIN:
-	case TARGET_STRING:
-		gtk_selection_data_set(data, data->target,
-				       8, (const guchar*)uri, strlen(uri));
-		break;
-	default:
-		break;
-	}
-}
-
 static void
 drag_data_received (GtkWidget *widget,
                     GdkDragContext *drag_context,
@@ -804,18 +703,6 @@ drag_data_received (GtkWidget *widget,
 
 	switch (info)
 	{
-	case TARGET_KAZEHAKASE_TAB:
-	{
-		GtkWidget *src_widget = gtk_drag_get_source_widget(drag_context);
-		KzTabLabel *src_kztab;
-
-		if (!KZ_IS_TAB_LABEL(src_widget)) return;
-		src_kztab = KZ_TAB_LABEL(src_widget);
-
-		kz_tab_label_move_page(src_kztab, kztab);
-		return;
-	}
-
 	case TARGET_NETSCAPE_URL:
 	case TARGET_TEXT_URI_LIST:
 	case TARGET_TEXT_PLAIN:
@@ -894,34 +781,6 @@ kz_tab_label_sync_to_profile (KzTabLabel *kztab)
 	g_free(color);
 }
 
-/* move kztab to dest_kztab's position */
-static void
-kz_tab_label_move_page(KzTabLabel *kztab, KzTabLabel *dest_kztab)
-{
-	GtkWidget *src_page;
-	KzNotebook *notebook;
-	gint dest_pos;
-
-	g_return_if_fail(dest_kztab->kz && dest_kztab->kzembed);
-	g_return_if_fail(kztab->kz && kztab->kzembed);
-
-	notebook = KZ_NOTEBOOK(dest_kztab->kz->notebook);
-	dest_pos = kz_notebook_page_num(notebook,
-					GTK_WIDGET(dest_kztab->kzembed));
-
-	src_page = GTK_WIDGET(kztab->kzembed);
-	if (dest_kztab->kz != kztab->kz)
-		kz_window_move_tab(dest_kztab->kz, src_page);
-	
-	kz_window_reorder_tab(dest_kztab->kz, src_page, dest_pos);
-	kz_actions_set_sensitive
-		(kztab->kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kztab->kz)));
-
-	if (dest_kztab->kz != kztab->kz)
-		gtk_widget_destroy(GTK_WIDGET(kztab));
-}
-
-
 static void
 make_progress_circle(GtkWidget *widget)
 {
@@ -1003,6 +862,24 @@ cb_title_changed (KzEmbed *embed, KzTabLabel *kztab)
 	g_free(title);
 }
 
+static void
+cb_location_changed (KzEmbed *embed, KzTabLabel *kztab)
+{
+	KzBookmark *bookmark = NULL;
+	guint cur;
+	GList *children;
+
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+
+	cur = kz_bookmark_get_current(kztab->history);
+	children = kz_bookmark_get_children(kztab->history);
+	bookmark = KZ_BOOKMARK(g_list_nth_data(children, cur));
+	g_list_free(children);
+
+	if (bookmark)
+		kz_bookmark_set_link(bookmark, kz_embed_get_location(embed));
+}
+
 static void
 cb_net_start (KzEmbed *embed, KzTabLabel *kztab)
 {
@@ -1261,6 +1138,8 @@ kz_tab_label_set_auto_refresh (KzTabLabel *kztab, gboolean auto_refresh)
 void
 kz_tab_label_set_history (KzTabLabel *kztab, KzBookmark *history)
 {	
+        gboolean allow_javacript;
+
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	g_object_unref(kztab->history);
@@ -1274,19 +1153,12 @@ kz_tab_label_set_history (KzTabLabel *kztab, KzBookmark *history)
 	{
 		kz_tab_label_set_auto_refresh(kztab, TRUE);
 	}
-	if (kz_bookmark_get_javascript(history))
-	{
-		kz_embed_set_allow_javascript(KZ_EMBED(kztab->kzembed), TRUE);
-		kz_tab_label_set_javascript(kztab, TRUE);
-	}
-	else
-	{
-		kz_embed_set_allow_javascript(KZ_EMBED(kztab->kzembed), FALSE);
-		kz_tab_label_set_javascript(kztab, FALSE);
-	}
+        
+        allow_javacript = kz_bookmark_get_javascript(history);
+        kz_embed_set_allow_javascript(KZ_EMBED(kztab->kzembed), allow_javacript);
+        kz_tab_label_set_javascript(kztab, allow_javacript);
 	
-	kz_embed_set_history(kztab->kzembed, 
-			     kztab->history);
+	kz_embed_set_history(kztab->kzembed, kztab->history);
 }
 static void
 kz_tab_label_set_visited (KzTabLabel *kztab)
@@ -1316,5 +1188,5 @@ kz_tab_label_set_visited (KzTabLabel *kztab)
 }
 
 /*
-vim:ts=8:nowrap:ai:expandtab
+vim:ts=8:nowrap:ai
 */
