@@ -2406,10 +2406,12 @@ motion_notify_event (GtkWidget *widget,
 	KzWindowPrivate *priv;
 	KzEmbed *kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(KZ_WINDOW(widget)));
 
+	if (!kzembed)
+		return FALSE;
+
 	kz = KZ_WINDOW(widget);
 	priv = KZ_WINDOW_GET_PRIVATE(kz);
 
-	/*gdk_window_get_pointer (GTK_WIDGET(kzembed)->window, &x, &y, &state);*/
 	gtk_widget_get_pointer(GTK_WIDGET(kzembed), &x, &y);
 
 	if (abs(x - priv->start_x) > 2 ||
