@@ -27,7 +27,6 @@
 #include "kz-gesture.h"
 #include "kz-embed-event.h"
 #include "kz-embed.h"
-#include "kz-favicon.h"
 #include "kz-popup-preview.h"
 #include "kz-bookmark.h"
 
@@ -77,11 +76,8 @@ struct _KzWindow
 	KzBookmark *history_search;
 
 	/* handle for favicon */
-	KzFavicon *kzfav;
 	KzPopupPreview *popup;
 	GtkWidget *popup_tablist;
-
-	gboolean   is_closing_all;
 };
 
 struct _KzWindowClass
@@ -100,24 +96,20 @@ struct _KzWindowClass
 };
 
 GType	          kz_window_get_type                 (void) G_GNUC_CONST;
-const GList      *kz_window_get_window_list          (void);
 GtkWidget        *kz_window_new                      (const gchar *url);
-GtkWidget        *kz_window_get_from_tab             (GtkWidget   *tab_widget);
 GtkWidget        *kz_window_open_new_tab             (KzWindow    *kz,
 						      const gchar *url);
-GtkWidget        *kz_window_open_new_tab_at_tail     (KzWindow    *kz,
-						      const gchar *url);
 GtkWidget        *kz_window_open_new_tab_with_parent (KzWindow    *kz,
 						      const gchar *url,
 						      GtkWidget   *parent);
 void              kz_window_close_tab                (KzWindow    *kz,
 						      GtkWidget   *widget);
 void              kz_window_close_all_tab            (KzWindow    *kz);
-void              kz_window_reorder_tab              (KzWindow    *kz,
-						      GtkWidget   *widget,
-						      gint         position);
-void              kz_window_move_tab                 (KzWindow    *kz,
+void		  kz_window_move_tab 		     (KzWindow    *src_kz,
+						      KzWindow    *dest_kz,
 						      GtkWidget   *widget);
+void		  kz_window_restore_tabs	     (KzWindow    *kz,
+						      KzBookmark  *tabs);
 void              kz_window_load_url                 (KzWindow    *kz,
 						      const gchar *url);
 void              kz_window_store_state              (KzWindow    *kz);
@@ -135,6 +127,8 @@ GtkWidget        *kz_window_get_tab_label            (KzWindow    *kz,
 
 GNode            *kz_window_get_tree                 (KzWindow    *kz);
 
+void              kz_window_set_location_entry_text  (KzWindow    *kz,
+						      const gchar *text);
 gboolean          kz_window_activate_action          (KzWindow    *kz,
 						      const gchar *name);
 gboolean          kz_window_activate_popup_action    (KzWindow    *kz,
@@ -145,7 +139,8 @@ gboolean          kz_window_activate_tabpop_action   (KzWindow    *kz,
 const KzEmbedEventMouse *
 		  kz_window_get_mouse_event_info     (KzWindow    *kz);
 
-void kz_window_append_closed_tab (KzWindow *kz, KzBookmark *bookmark);
+void		  kz_window_append_closed_tab	     (KzWindow    *kz,
+						      KzBookmark  *bookmark);
 
 #define KZ_WINDOW_NTH_PAGE(kz, n) \
 	(KZ_IS_WINDOW(kz) ? gtk_notebook_get_nth_page(GTK_NOTEBOOK(KZ_WINDOW(kz)->notebook),n) : NULL)
