@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.c,v 1.25 2005/05/09 01:20:12 ikezoe Exp $
+ *  $Id: kz-xml.c 3352 2008-01-09 12:42:30Z furyo $
  */
 
 #include "kz-xml.h"
@@ -25,7 +25,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
-#include "gobject-utils.h"
 
 typedef struct _KzXMLPrivate    KzXMLPrivate;
 struct _KzXMLPrivate
@@ -34,29 +33,22 @@ struct _KzXMLPrivate
 };
 #define KZ_XML_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_XML, KzXMLPrivate))
 
-static void kz_xml_class_init   (KzXMLClass *klass);
-static void kz_xml_init         (KzXML      *xml);
-static void kz_xml_dispose      (GObject    *object);
+static void dispose      (GObject    *object);
 
 static void kz_xml_attr_free    (KzXMLAttr *attr);
-
-static GObjectClass *parent_class = NULL;
+gchar *get_cdata_as_plaintext(gpointer content);
 
 
-KZ_OBJECT_GET_TYPE(kz_xml, "KzXML", KzXML,
-		   kz_xml_class_init, kz_xml_init,
-		   G_TYPE_OBJECT)
-
+G_DEFINE_TYPE(KzXML, kz_xml, G_TYPE_OBJECT)
 
 static void
 kz_xml_class_init (KzXMLClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose  = kz_xml_dispose;
+	object_class->dispose  = dispose;
 	g_type_class_add_private (object_class, sizeof(KzXMLPrivate));
 }
 
@@ -75,7 +67,7 @@ kz_xml_init (KzXML *xml)
 
 
 static void
-kz_xml_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzXML *xml = KZ_XML(object);
 
@@ -92,8 +84,8 @@ kz_xml_dispose (GObject *object)
 		kz_xml_node_unref(xml->root);
 	xml->root = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_xml_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_xml_parent_class)->dispose(object);
 }
 
 
@@ -506,6 +498,12 @@ kz_xml_node_append_xml_string (KzXMLNode *node, GString *gstr)
 			g_free(escaped);
 		}
 	}
+	else if (node->type == KZ_XML_NODE_CDATA)
+	{
+		gchar *cdata_text = get_cdata_as_plaintext(node->content);
+		g_string_append(gstr, cdata_text);
+		g_free(cdata_text);
+	}
 	else
 	{
 		g_string_append(gstr, node->content);
@@ -538,6 +536,13 @@ kz_xml_node_append_string (KzXMLNode *node, GString *gstr)
 
 	if (node->type == KZ_XML_NODE_TEXT)
 		g_string_append(gstr, node->content);
+	if (node->type == KZ_XML_NODE_CDATA)
+	{
+		gchar *cdata_text = get_cdata_as_plaintext(node->content);
+		g_string_append(gstr, cdata_text);
+		g_free(cdata_text);
+	}
+
 
 	for (list = node->children; list; list = g_list_next(list))
 		kz_xml_node_append_string(list->data, gstr);
@@ -798,6 +803,28 @@ kz_xml_get_root_element (KzXML *xml)
 	return NULL;
 }
 
+void
+kz_xml_set_root_element (KzXML *xml, KzXMLNode *node)
+{
+	KzXMLNode *prev_node;
+	g_return_if_fail(KZ_IS_XML(xml));
+
+	prev_node = kz_xml_node_first_child(xml->root);
+	for (; prev_node; prev_node = kz_xml_node_next(prev_node))
+	{
+		if (prev_node->type == KZ_XML_NODE_ELEMENT)
+		{
+			break;
+		}
+	}
+
+	if (prev_node)
+		kz_xml_node_remove_child(xml->root, prev_node);
+
+	if (node)
+		kz_xml_node_append_child(xml->root, node);
+}
+
 
 gboolean
 kz_xml_node_is_element (KzXMLNode *node)
@@ -834,6 +861,7 @@ kz_xml_node_insert_before (KzXMLNode *node,
 	}
 	node->children = g_list_insert_before(node->children, list, child);
 	child->parent = node;
+	kz_xml_node_ref(child);
 }
 
 
@@ -845,6 +873,7 @@ kz_xml_node_remove_child (KzXMLNode *node, KzXMLNode *child)
 
 	node->children = g_list_remove(node->children, child);
 	child->parent = NULL;
+	kz_xml_node_unref(child);
 
 	return child;
 }
@@ -1020,3 +1049,32 @@ kz_xml_node_arrange_indent(KzXMLNode *parent, guint indent_level)
 		kz_xml_node_arrange_indent(node, indent_level + 1);
 	}
 }
+
+gchar *
+get_cdata_as_plaintext(gpointer content)
+{
+	gchar *cdata_text;
+	gchar *plain_text;
+	gchar *str;
+	gint i, j;
+
+	str = (char*)content;
+
+	i = j = strlen("<![CDATA[");
+	while(str[i] != '\0')
+	{
+		if(str[i] == ']' && str[i+3] == '\0')
+		{
+			break;
+		}
+		i++;
+	}
+
+	cdata_text = g_strndup(str+j, i-j);
+	plain_text = remove_tag((const gchar*)cdata_text, (gsize)strlen(cdata_text));
+
+	if(cdata_text)
+		g_free(cdata_text);
+
+	return plain_text;
+}
