@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.h,v 1.11 2005/05/09 01:20:12 ikezoe Exp $
+ *  $Id: kz-xml.h 3100 2007-03-30 00:14:13Z kous $
  */
 
 #ifndef KZ_XML_H
@@ -112,6 +112,8 @@ void         kz_xml_clear_content          (KzXML         *xml);
 KzXMLNode   *kz_xml_node_new               (KzXML         *xml,
 					    KzXMLNodeType  type);
 KzXMLNode   *kz_xml_get_root_element       (KzXML         *xml);
+void         kz_xml_set_root_element       (KzXML         *xml,
+					    KzXMLNode     *node);
 KzXMLNode   *kz_xml_node_ref               (KzXMLNode     *node);
 void         kz_xml_node_unref             (KzXMLNode     *node);
 gboolean     kz_xml_node_is_element        (KzXMLNode     *node);
