@@ -35,16 +35,14 @@
 #include "kz-actions-tab.h"
 #include "utils.h"
 
-KzApp	       *kz_app		  = NULL;
-
 static gchar** action_array;
 static gchar* geometry_string;
 static gboolean show_version;
 
-static GOptionEntry entries[] = {
-	{ "action", 'a', 0, G_OPTION_ARG_STRING_ARRAY, &action_array, "Execute action", NULL},
-	{ "geometry", 'g', 0, G_OPTION_ARG_STRING, &geometry_string, " Position the window on the screen", NULL },
-	{ "version", 'v', 0, G_OPTION_ARG_NONE, &show_version, "Show this version", NULL },
+static const GOptionEntry entries[] = {
+	{ "action", 'a', 0, G_OPTION_ARG_STRING_ARRAY, &action_array, N_("Execute action"), NULL},
+	{ "geometry", 'g', 0, G_OPTION_ARG_STRING, &geometry_string, N_("Position the window on the screen"), NULL },
+	{ "version", 'v', 0, G_OPTION_ARG_NONE, &show_version, N_("Show this version"), NULL },
 	{ NULL }
 };
 
@@ -135,7 +133,7 @@ process_args(int argc, char** argv)
 
 #warning This function has side effect!
 
-	if (!kz_app) return;
+	if (!kz_app_get()) return;
 
 	list = KZ_GET_WINDOW_LIST;
 	if (!list || !list->data || !KZ_IS_WINDOW(list->data))
@@ -153,7 +151,7 @@ process_args(int argc, char** argv)
 	kz = KZ_WINDOW(list->data);
 	for(i = 1; i < argc; i++)
 	{
-		gchar *uri = complement_scheme(argv[i]);
+		gchar *uri = kz_utils_complement_scheme(argv[i]);
 		gdk_window_raise(GTK_WIDGET(kz)->window);
 
 		kz_window_open_new_tab(kz, uri);
@@ -174,7 +172,7 @@ enum {
 	TARGET_STRING
 };
 
-static GtkTargetEntry targets[]={
+static const GtkTargetEntry targets[]={
 	{"STRING", 0, TARGET_STRING},
 };
 static GdkAtom  atom_kz0;  /* for checking process  */
@@ -425,6 +423,7 @@ main (int argc, char *argv[])
 	gboolean retval;
 	GError *error = NULL;
 	gboolean restore = FALSE;
+	KzApp *kz_app;
 
         /* initialize */
 #ifdef G_OS_WIN32
@@ -432,14 +431,14 @@ main (int argc, char *argv[])
 		gchar *locale_dir;
 		locale_dir = g_build_filename(kz_win32_base_path(),
 					      "share", "locale", NULL);
-		bindtextdomain(PACKAGE, locale_dir);
+		bindtextdomain(GETTEXT_PACKAGE, locale_dir);
 		g_free(locale_dir);
 	}
 #else
-	bindtextdomain(PACKAGE, LOCALEDIR);
+	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
 #endif
-	bind_textdomain_codeset(PACKAGE, "UTF-8");
-	textdomain(PACKAGE);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 
 	if (!g_thread_supported()) g_thread_init(NULL);
 
@@ -490,16 +489,12 @@ main (int argc, char *argv[])
 	/* create window */
 	KZ_CONF_GET("Session", "restore", restore, BOOL);
 	if (restore)
-	{
 		window = kz_app_restore_session(kz_app);
-		if (!window)
-			window = kz_app_create_new_window(kz_app, NULL);
-	}
 	else
 		window = kz_app_create_new_window(kz_app, NULL);
 
        	/*
-	 * gtk_window_pargse_geometry() needs to be called
+	 * gtk_window_parse_geometry() needs to be called
 	 * before gtk_widget_show().
 	 */
 	if(geometry_string)
