@@ -47,7 +47,6 @@
 #include "kz-profile.h"
 #include "kz-proxy-item.h"
 #include "kz-prompt-dialog.h"
-#include "kz-base64.h"
 #include "eggmd5.h"
 
 #define BUFFER_SIZE 256
@@ -1405,7 +1404,7 @@ kz_http_show_dialog (KzHTTP *http)
 		 {
 			gchar *str, *base64;
 			str = g_strdup_printf("%s:%s", user, pass);
-			base64 = kz_base64_encode(str);
+			base64 = g_base64_encode((guchar *)str, strlen(str));
 			ap->string = g_strdup_printf("Basic %s", base64);
 			g_free(str);
 			if (base64)
