@@ -23,7 +23,6 @@
 #include <glib/gi18n.h>
 
 #include "kz-xmlrpc.h"
-#include "gobject-utils.h"
 #include "kz-http.h"
 #include "kz-xml.h"
 
@@ -39,17 +38,15 @@ enum {
 
 #define KZ_XML_RPC_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_XML_RPC, KzXMLRPCPrivate))
 
-static void kz_xml_rpc_class_init      (KzXMLRPCClass *klass);
-static void kz_xml_rpc_init            (KzXMLRPC *xmlrpc);
-static void kz_xml_rpc_set_property    (GObject *object,
-				        guint prop_id,
-				        const GValue *value,
-				        GParamSpec *pspec);
-static void kz_xml_rpc_get_property    (GObject *object,
-				        guint prop_id,
-				        GValue *value,
-				        GParamSpec *pspec);
-static void kz_xml_rpc_dispose         (GObject *object);
+static void set_property    (GObject *object,
+                             guint prop_id,
+                             const GValue *value,
+                             GParamSpec *pspec);
+static void get_property    (GObject *object,
+                             guint prop_id,
+                             GValue *value,
+                             GParamSpec *pspec);
+static void dispose         (GObject *object);
 
 typedef struct _KzXMLRPCPrivate KzXMLRPCPrivate;
 struct _KzXMLRPCPrivate 
@@ -60,24 +57,20 @@ struct _KzXMLRPCPrivate
 };
 
 
-static GObjectClass *parent_class = NULL;
 static gint kz_xml_rpc_signals[XMLRPC_LAST_SIGNAL] = {0};
 
-KZ_OBJECT_GET_TYPE(kz_xml_rpc, "KzXMLRPC", KzXMLRPC,
-		   kz_xml_rpc_class_init, kz_xml_rpc_init,
-		   G_TYPE_OBJECT)
+G_DEFINE_TYPE(KzXMLRPC, kz_xml_rpc, G_TYPE_OBJECT)
 
 static void
 kz_xml_rpc_class_init (KzXMLRPCClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose      = kz_xml_rpc_dispose;
-	object_class->set_property = kz_xml_rpc_set_property;
-	object_class->get_property = kz_xml_rpc_get_property;
+	object_class->dispose      = dispose;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 	
 	klass->xml_rpc_completed   = NULL;
 
@@ -115,7 +108,7 @@ kz_xml_rpc_init (KzXMLRPC *xmlrpc)
 
 
 void
-kz_xml_rpc_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzXMLRPCPrivate *priv = KZ_XML_RPC_GET_PRIVATE (object);
 
@@ -137,16 +130,16 @@ kz_xml_rpc_dispose (GObject *object)
 
 	priv->xmlrpc_uri = NULL;
 	
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_xml_rpc_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_xml_rpc_parent_class)->dispose(object);
 }
 
 
 static void
-kz_xml_rpc_set_property (GObject *object,
-		         guint prop_id,
-		         const GValue *value,
-		         GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzXMLRPCPrivate *priv = KZ_XML_RPC_GET_PRIVATE (object);
 
@@ -163,10 +156,10 @@ kz_xml_rpc_set_property (GObject *object,
 
 
 static void
-kz_xml_rpc_get_property (GObject *object,
-		         guint prop_id,
-		         GValue *value,
-		         GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzXMLRPCPrivate *priv = KZ_XML_RPC_GET_PRIVATE (object);
 
