@@ -59,11 +59,11 @@ static void        prefs_proxy_set_sensitive      (KzPrefsProxy *prefsui);
 
 static KzPrefsWinPageEntry prefs_entry =
 {
-	path:            N_("/Proxy"),
-	priority_hint:   0,
-	ui_level:        KZ_UI_LEVEL_ALL,
-	create:          prefs_proxy_create,
-	response:        prefs_proxy_response,
+	/* .path          = */ N_("/Proxy"),
+	/* .priority_hint = */ 0,
+	/* .ui_level      = */ KZ_UI_LEVEL_ALL,
+	/* .create        = */ prefs_proxy_create,
+	/* .response      = */ prefs_proxy_response,
 };
 
 struct _KzPrefsProxy
@@ -801,11 +801,11 @@ prefs_proxy_create (void)
 }
 
 #define KZ_CONF_PROXY_SET(s, k, v, t)					\
-		  kz_profile_set_value(kz_proxy,			\
+		  kz_profile_set_value(KZ_GET_PROXY,			\
 				       s, k, &(v), sizeof(v),		\
 				       KZ_PROFILE_VALUE_TYPE_##t)
 #define KZ_CONF_PROXY_SET_STR(s, k, v)					\
-		  kz_profile_set_value(kz_proxy,			\
+		  kz_profile_set_value(KZ_GET_PROXY,			\
 				       s, k,				\
 				       (gchar *)v,			\
 				       strlen((gchar *)v) + 1,		\
@@ -828,9 +828,9 @@ prefs_proxy_save_proxy (KzPrefsProxy *prefsui)
 				(GTK_TOGGLE_BUTTON(prefsui->use_proxy));
 	KZ_CONF_SET("Global", "use_proxy", use_proxy, BOOL);
 
-	list = kz_profile_enum_section(kz_proxy);
+	list = kz_profile_enum_section(KZ_GET_PROXY);
 	for (node = list; node; node = g_list_next(node))
-		kz_profile_delete_section(kz_proxy, node->data);
+		kz_profile_delete_section(KZ_GET_PROXY, node->data);
 	g_list_free(list);
 
 	for (exist = gtk_tree_model_get_iter_first(model, &iter);
@@ -919,7 +919,7 @@ prefs_proxy_select_proxy(KzPrefsProxy *prefsui)
 	}
 	else
 	{
-		kz_profile_delete_key(kz_global_profile, "Global", "proxy_name");
+		kz_profile_delete_key(KZ_GET_GLOBAL_PROFILE, "Global", "proxy_name");
 	}
 }
 
