@@ -17,14 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-sidebar.c,v 1.12 2006/08/25 15:06:38 kous Exp $
+ *  $Id: kz-bookmarks-sidebar.c 2863 2007-03-14 06:43:16Z ikezoe $
  */
 
 #include "kz-bookmarks-sidebar.h"
 
 #include <glib/gi18n.h>
 #include "kazehakase.h"
-#include "gobject-utils.h"
 #include "kz-actions.h"
 #include "kz-bookmarks-view.h"
 
@@ -36,17 +35,15 @@ enum {
 
 
 /* Object class methods */
-static void     kz_bookmarks_sidebar_class_init   (KzBookmarksSidebarClass *klass);
-static void     kz_bookmarks_sidebar_init         (KzBookmarksSidebar      *sidebar);
-static void     kz_bookmarks_sidebar_dispose      (GObject      *obj);
-static void     kz_bookmarks_sidebar_set_property (GObject      *object,
-						   guint         prop_id,
-						   const GValue *value,
-						   GParamSpec   *pspec);
-static void     kz_bookmarks_sidebar_get_property (GObject      *object,
-						   guint         prop_id,
-						   GValue       *value,
-						   GParamSpec   *pspec);
+static void     dispose      (GObject      *obj);
+static void     set_property (GObject      *object,
+                              guint         prop_id,
+                              const GValue *value,
+                              GParamSpec   *pspec);
+static void     get_property (GObject      *object,
+                              guint         prop_id,
+                              GValue       *value,
+                              GParamSpec   *pspec);
 
 static GtkWidget *kz_bookmarks_sidebar_new_with_entry (KzSidebarEntry *entry,
 						       KzSidebar   *sidebar);
@@ -58,14 +55,12 @@ static gboolean cb_button_release                 (GtkWidget          *widget,
 
 static KzSidebarEntry kz_sidebar_bookmarks = 
 {
-	priority_hint: 0,
-	label:         N_("Bookmarks"),
-	icon:          NULL,
-	create:        kz_bookmarks_sidebar_new_with_entry,
+	/* .priority_hint = */ 0,
+	/* .label         = */ N_("Bookmarks"),
+	/* .icon          = */ NULL,
+	/* .create        = */ kz_bookmarks_sidebar_new_with_entry,
 };
 
-static GtkVBoxClass *parent_class = NULL;
-
 
 KzSidebarEntry *
 kz_bookmarks_sidebar_get_entry (gint idx)
@@ -76,23 +71,18 @@ kz_bookmarks_sidebar_get_entry (gint idx)
 		return NULL;
 }
 
-
-KZ_OBJECT_GET_TYPE(kz_bookmarks_sidebar, "KzBookmarksSidebar", KzBookmarksSidebar,
-		   kz_bookmarks_sidebar_class_init, kz_bookmarks_sidebar_init,
-		   GTK_TYPE_VBOX)
-
+G_DEFINE_TYPE(KzBookmarksSidebar, kz_bookmarks_sidebar, GTK_TYPE_VBOX)
 
 static void
 kz_bookmarks_sidebar_class_init (KzBookmarksSidebarClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent(klass);
 	gobject_class = (GObjectClass *) klass;
 
-	gobject_class->dispose      = kz_bookmarks_sidebar_dispose;
-	gobject_class->set_property = kz_bookmarks_sidebar_set_property;
-	gobject_class->get_property = kz_bookmarks_sidebar_get_property;
+	gobject_class->dispose      = dispose;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	g_object_class_install_property
 		(gobject_class,
@@ -123,7 +113,7 @@ kz_bookmarks_sidebar_init (KzBookmarksSidebar *sidebar)
 
 	view = kz_bookmarks_view_new();
 	kz_bookmarks_view_set_root_folder(KZ_BOOKMARKS_VIEW(view),
-					  KZ_BOOKMARK(kz_bookmarks),
+					  KZ_BOOKMARK(KZ_GET_ROOT_BOOKMARK),
 					  TRUE, FALSE, FALSE, FALSE);
 	gtk_container_add(GTK_CONTAINER(scrwin), view);
 	g_signal_connect(view, "button-release-event",
@@ -134,7 +124,7 @@ kz_bookmarks_sidebar_init (KzBookmarksSidebar *sidebar)
 
 
 static void
-kz_bookmarks_sidebar_dispose (GObject *obj)
+dispose (GObject *obj)
 {
 	KzBookmarksSidebar *sidebar = KZ_BOOKMARKS_SIDEBAR(obj);
 
@@ -142,16 +132,16 @@ kz_bookmarks_sidebar_dispose (GObject *obj)
 		g_object_unref(sidebar->sidebar);
 	sidebar->sidebar = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(obj);
+	if (G_OBJECT_CLASS (kz_bookmarks_sidebar_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_bookmarks_sidebar_parent_class)->dispose(obj);
 }
 
 
 static void
-kz_bookmarks_sidebar_set_property (GObject         *object,
-				   guint            prop_id,
-				   const GValue    *value,
-				   GParamSpec      *pspec)
+set_property (GObject         *object,
+              guint            prop_id,
+              const GValue    *value,
+              GParamSpec      *pspec)
 {
 	KzBookmarksSidebar *sidebar = KZ_BOOKMARKS_SIDEBAR(object);
   
@@ -168,10 +158,10 @@ kz_bookmarks_sidebar_set_property (GObject         *object,
 
 
 static void
-kz_bookmarks_sidebar_get_property (GObject         *object,
-				   guint            prop_id,
-				   GValue          *value,
-				   GParamSpec      *pspec)
+get_property (GObject         *object,
+              guint            prop_id,
+              GValue          *value,
+              GParamSpec      *pspec)
 {
 	KzBookmarksSidebar *sidebar = KZ_BOOKMARKS_SIDEBAR(object);
 
