@@ -17,14 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-downloader-sidebar.c,v 1.12 2006/08/25 15:06:38 kous Exp $
+ *  $Id: kz-downloader-sidebar.c 3228 2007-07-28 14:50:23Z kous $
  */
 
 #include "kz-downloader-sidebar.h"
 
 #include <glib/gi18n.h>
 #include "kazehakase.h"
-#include "gobject-utils.h"
 
 enum {
 	PROP_0,
@@ -43,17 +42,15 @@ enum {
 
 
 /* Object class methods */
-static void     kz_downloader_sidebar_class_init   (KzDownloaderSidebarClass *klass);
-static void     kz_downloader_sidebar_init         (KzDownloaderSidebar      *sidebar);
-static void     kz_downloader_sidebar_dispose      (GObject      *obj);
-static void     kz_downloader_sidebar_set_property (GObject      *object,
-						   guint         prop_id,
-						   const GValue *value,
-						   GParamSpec   *pspec);
-static void     kz_downloader_sidebar_get_property (GObject      *object,
-						   guint         prop_id,
-						   GValue       *value,
-						   GParamSpec   *pspec);
+static void     dispose      (GObject      *obj);
+static void     set_property (GObject      *object,
+                              guint         prop_id,
+                              const GValue *value,
+                              GParamSpec   *pspec);
+static void     get_property (GObject      *object,
+                              guint         prop_id,
+                              GValue       *value,
+                              GParamSpec   *pspec);
 
 static GtkWidget *kz_downloader_sidebar_new_with_entry (KzSidebarEntry *entry,
 							KzSidebar   *sidebar);
@@ -61,14 +58,12 @@ static GtkWidget *kz_downloader_sidebar_new_with_entry (KzSidebarEntry *entry,
 
 static KzSidebarEntry kz_sidebar_downloader = 
 {
-	priority_hint: 0,
-	label:         N_("Downloader"),
-	icon:          NULL,
-	create:        kz_downloader_sidebar_new_with_entry,
+	/* .priority_hint = */ 0,
+	/* .label         = */ N_("Downloader"),
+	/* .icon          = */ NULL,
+	/* .create        = */ kz_downloader_sidebar_new_with_entry,
 };
 
-static GtkVBoxClass *parent_class = NULL;
-
 
 KzSidebarEntry *
 kz_downloader_sidebar_get_entry (gint idx)
@@ -79,23 +74,18 @@ kz_downloader_sidebar_get_entry (gint idx)
 		return NULL;
 }
 
-
-KZ_OBJECT_GET_TYPE(kz_downloader_sidebar, "KzDownloaderSidebar", KzDownloaderSidebar,
-		   kz_downloader_sidebar_class_init, kz_downloader_sidebar_init,
-		   GTK_TYPE_VBOX)
-
+G_DEFINE_TYPE(KzDownloaderSidebar, kz_downloader_sidebar, GTK_TYPE_VBOX)
 
 static void
 kz_downloader_sidebar_class_init (KzDownloaderSidebarClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent(klass);
 	gobject_class = (GObjectClass *) klass;
 
-	gobject_class->dispose      = kz_downloader_sidebar_dispose;
-	gobject_class->set_property = kz_downloader_sidebar_set_property;
-	gobject_class->get_property = kz_downloader_sidebar_get_property;
+	gobject_class->dispose      = dispose;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	g_object_class_install_property
 		(gobject_class,
@@ -216,7 +206,7 @@ set_progress_func (GtkTreeModel *model,
 	{
 		gdouble progress;
 
-		progress = kz_downloader_get_percent(downloader) / 100.0;
+		progress = kz_downloader_get_percent(downloader);
 		gtk_list_store_set(GTK_LIST_STORE(model), iter,
 				   COLUMN_PROGRESS, progress,
 				   TERMINATOR);
@@ -283,7 +273,7 @@ kz_downloader_sidebar_init (KzDownloaderSidebar *sidebar)
 	cell = gtk_cell_renderer_progress_new();
 	column = gtk_tree_view_column_new_with_attributes
 			(_("Progress"), cell,
-			 "percentage", COLUMN_PROGRESS,
+			 "value", COLUMN_PROGRESS,
 			 NULL);
 	gtk_tree_view_append_column(tree_view, column);
 
@@ -309,7 +299,7 @@ kz_downloader_sidebar_init (KzDownloaderSidebar *sidebar)
 
 
 static void
-kz_downloader_sidebar_dispose (GObject *obj)
+dispose (GObject *obj)
 {
 	KzDownloaderSidebar *sidebar = KZ_DOWNLOADER_SIDEBAR(obj);
 
@@ -332,16 +322,16 @@ kz_downloader_sidebar_dispose (GObject *obj)
 	}
 	sidebar->downloader_group = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(obj);
+	if (G_OBJECT_CLASS (kz_downloader_sidebar_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_downloader_sidebar_parent_class)->dispose(obj);
 }
 
 
 static void
-kz_downloader_sidebar_set_property (GObject         *object,
-				    guint            prop_id,
-				    const GValue    *value,
-				    GParamSpec      *pspec)
+set_property (GObject         *object,
+              guint            prop_id,
+              const GValue    *value,
+              GParamSpec      *pspec)
 {
 	KzDownloaderSidebar *sidebar = KZ_DOWNLOADER_SIDEBAR(object);
   
@@ -358,10 +348,10 @@ kz_downloader_sidebar_set_property (GObject         *object,
 
 
 static void
-kz_downloader_sidebar_get_property (GObject         *object,
-				    guint            prop_id,
-				    GValue          *value,
-				    GParamSpec      *pspec)
+get_property (GObject         *object,
+              guint            prop_id,
+              GValue          *value,
+              GParamSpec      *pspec)
 {
 	KzDownloaderSidebar *sidebar = KZ_DOWNLOADER_SIDEBAR(object);
 
