@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 3S30, Boston, MA 02111-1307, USA.
  *
- * $Id: kz-dlist.c,v 1.6 2005/05/09 01:20:13 ikezoe Exp $
+ * $Id: kz-dlist.c 2644 2006-12-02 12:19:08Z ikezoe $
  */
 
 #include "kz-dlist.h"
@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <glib/gi18n.h>
 
-#include "gobject-utils.h"
 #include "gtk-utils.h"
 
 enum {
@@ -53,19 +52,16 @@ enum {
 	(gtk_tree_model_iter_n_children(gtk_tree_view_get_model(GTK_TREE_VIEW(widget)), NULL))
 
 
-static void       kz_dlist_init                     (KzDList *dlist);
-static void       kz_dlist_class_init               (KzDListClass *klass);
-
 /* object class functions */
-static void       kz_dlist_dispose                  (GObject      *object);
-static void       kz_dlist_set_property             (GObject      *object,
-						     guint         prop_id,
-						     const GValue *value,
-						     GParamSpec   *pspec);
-static void       kz_dlist_get_property             (GObject      *object,
-						     guint         prop_id,
-						     GValue       *value,
-						     GParamSpec   *pspec);
+static void       dispose                  (GObject      *object);
+static void       set_property             (GObject      *object,
+                                            guint         prop_id,
+                                            const GValue *value,
+                                            GParamSpec   *pspec);
+static void       get_property             (GObject      *object,
+                                            guint         prop_id,
+                                            GValue       *value,
+                                            GParamSpec   *pspec);
 
 /* private functions */
 static void       kz_dlist_available_list_updated   (KzDList   *dlist);
@@ -83,14 +79,9 @@ static void       cb_down_button_pressed            (GtkButton *button,
 						     gpointer   data);
 
 
-static GtkHBoxClass *parent_class = NULL;
 static gint kz_dlist_signals[LAST_SIGNAL] = {0};
 
-
-KZ_OBJECT_GET_TYPE(kz_dlist, "KzDList", KzDList,
-                   kz_dlist_class_init, kz_dlist_init,
-                   GTK_TYPE_HBOX)
-
+G_DEFINE_TYPE(KzDList, kz_dlist, GTK_TYPE_HBOX)
 
 static void
 kz_dlist_class_init (KzDListClass *klass)
@@ -98,11 +89,10 @@ kz_dlist_class_init (KzDListClass *klass)
 	GObjectClass *gobject_class;
 
 	gobject_class = (GObjectClass *) klass;
-	parent_class = gtk_type_class (gtk_hbox_get_type ());
 
-	gobject_class->dispose = kz_dlist_dispose;
-	gobject_class->set_property = kz_dlist_set_property;
-	gobject_class->get_property = kz_dlist_get_property;
+	gobject_class->dispose      = dispose;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	g_object_class_install_property(
 		gobject_class,
@@ -276,7 +266,7 @@ kz_dlist_init (KzDList *dlist)
 
 
 static void
-kz_dlist_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzDList *dlist = KZ_DLIST(object);
 
@@ -284,19 +274,15 @@ kz_dlist_dispose (GObject *object)
 	g_list_free(dlist->available_list);
 	dlist->available_list = NULL;
 
-	if (G_OBJECT_CLASS(parent_class)->dispose)
-		G_OBJECT_CLASS(parent_class)->dispose(object);
+	if (G_OBJECT_CLASS(kz_dlist_parent_class)->dispose)
+		G_OBJECT_CLASS(kz_dlist_parent_class)->dispose(object);
 }
 
-
-/* KZ_OBJECT_FINALIZE(kz_dlist, KzDList) */
-
-
 static void
-kz_dlist_set_property (GObject *object,
-		       guint prop_id,
-		       const GValue *value,
-		       GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzDList *dlist = KZ_DLIST(object);
 
@@ -318,10 +304,10 @@ kz_dlist_set_property (GObject *object,
 
 
 static void
-kz_dlist_get_property (GObject *object,
-		       guint prop_id,
-		       GValue *value,
-		       GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzDList *dlist = KZ_DLIST(object);
 	const gchar *text;
